# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '.\GENOVIS_GUI.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.
import sys
import os
import io
import contextlib
import argparse
from PyQt5 import QtCore, QtGui, QtWidgets
os.environ["GENOVIS_GUI"] = "1"
BASE_DIR=os.path.dirname(os.path.abspath(__file__))
ICON_PATH=os.path.join(BASE_DIR, "resources", "GENOVIS.ico")
LOGO_PATH=os.path.join(BASE_DIR, "resources", "GENOVIS.png")
class Ui_GENOVIS_GUI(object):
    def setupUi(self, GENOVIS_GUI):
        GENOVIS_GUI.setObjectName("GENOVIS_GUI")
        GENOVIS_GUI.resize(724, 712)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(GENOVIS_GUI.sizePolicy().hasHeightForWidth())
        GENOVIS_GUI.setSizePolicy(sizePolicy)
        GENOVIS_GUI.setMinimumSize(QtCore.QSize(724, 712))
        GENOVIS_GUI.setMaximumSize(QtCore.QSize(724, 712))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(ICON_PATH), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(ICON_PATH), QtGui.QIcon.Normal, QtGui.QIcon.On)
        GENOVIS_GUI.setWindowIcon(icon)
        GENOVIS_GUI.setStyleSheet("font: 10pt \"MS Shell Dlg 2\";")
        GENOVIS_GUI.setIconSize(QtCore.QSize(400, 400))
        GENOVIS_GUI.setAnimated(False)
        self.centralwidget = QtWidgets.QWidget(GENOVIS_GUI)
        self.centralwidget.setObjectName("centralwidget")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setGeometry(QtCore.QRect(10, 260, 701, 421))
        self.tabWidget.setMinimumSize(QtCore.QSize(701, 421))
        self.tabWidget.setMaximumSize(QtCore.QSize(701, 421))
        self.tabWidget.setIconSize(QtCore.QSize(200, 100))
        self.tabWidget.setObjectName("tabWidget")
        self.mapden_tab = QtWidgets.QWidget()
        self.mapden_tab.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.mapden_tab.setAutoFillBackground(False)
        self.mapden_tab.setObjectName("mapden_tab")
        self.pushButton_mapden_run = QtWidgets.QPushButton(self.mapden_tab)
        self.pushButton_mapden_run.setGeometry(QtCore.QRect(20, 350, 650, 30))
        self.pushButton_mapden_run.setMinimumSize(QtCore.QSize(650, 30))
        self.pushButton_mapden_run.setObjectName("pushButton_mapden_run")
        self.splitter_21 = QtWidgets.QSplitter(self.mapden_tab)
        self.splitter_21.setGeometry(QtCore.QRect(20, 11, 664, 80))
        self.splitter_21.setMinimumSize(QtCore.QSize(664, 80))
        self.splitter_21.setMaximumSize(QtCore.QSize(641, 70))
        self.splitter_21.setOrientation(QtCore.Qt.Vertical)
        self.splitter_21.setObjectName("splitter_21")
        self.splitter_2 = QtWidgets.QSplitter(self.splitter_21)
        self.splitter_2.setMinimumSize(QtCore.QSize(641, 21))
        self.splitter_2.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_2.setObjectName("splitter_2")
        self.label_m_mapden = QtWidgets.QLabel(self.splitter_2)
        self.label_m_mapden.setMinimumSize(QtCore.QSize(52, 20))
        self.label_m_mapden.setMaximumSize(QtCore.QSize(52, 20))
        self.label_m_mapden.setWhatsThis("")
        self.label_m_mapden.setWordWrap(True)
        self.label_m_mapden.setObjectName("label_m_mapden")
        self.lineEdit_m_mapden = QtWidgets.QLineEdit(self.splitter_2)
        self.lineEdit_m_mapden.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_m_mapden.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_m_mapden.setObjectName("lineEdit_m_mapden")
        self.pushButton_m_mapden = QtWidgets.QPushButton(self.splitter_2)
        self.pushButton_m_mapden.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_m_mapden.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_m_mapden.setAutoDefault(False)
        self.pushButton_m_mapden.setObjectName("pushButton_m_mapden")
        self.splitter_18 = QtWidgets.QSplitter(self.splitter_21)
        self.splitter_18.setMinimumSize(QtCore.QSize(641, 21))
        self.splitter_18.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_18.setObjectName("splitter_18")
        self.label_i_mapden = QtWidgets.QLabel(self.splitter_18)
        self.label_i_mapden.setMinimumSize(QtCore.QSize(52, 20))
        self.label_i_mapden.setMaximumSize(QtCore.QSize(52, 20))
        self.label_i_mapden.setObjectName("label_i_mapden")
        self.lineEdit_i_mapden = QtWidgets.QLineEdit(self.splitter_18)
        self.lineEdit_i_mapden.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_i_mapden.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_i_mapden.setObjectName("lineEdit_i_mapden")
        self.pushButton_i_mapden = QtWidgets.QPushButton(self.splitter_18)
        self.pushButton_i_mapden.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_i_mapden.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_i_mapden.setAutoDefault(False)
        self.pushButton_i_mapden.setFlat(False)
        self.pushButton_i_mapden.setObjectName("pushButton_i_mapden")
        self.splitter_19 = QtWidgets.QSplitter(self.splitter_21)
        self.splitter_19.setMinimumSize(QtCore.QSize(641, 20))
        self.splitter_19.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_19.setObjectName("splitter_19")
        self.label_mapden_o = QtWidgets.QLabel(self.splitter_19)
        self.label_mapden_o.setMinimumSize(QtCore.QSize(62, 20))
        self.label_mapden_o.setMaximumSize(QtCore.QSize(62, 20))
        self.label_mapden_o.setObjectName("label_mapden_o")
        self.lineEdit_mapden_o = QtWidgets.QLineEdit(self.splitter_19)
        self.lineEdit_mapden_o.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_mapden_o.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_mapden_o.setObjectName("lineEdit_mapden_o")
        self.pushButton_mapden_o = QtWidgets.QPushButton(self.splitter_19)
        self.pushButton_mapden_o.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_mapden_o.setMaximumSize(QtCore.QSize(75, 30))
        self.pushButton_mapden_o.setAutoDefault(False)
        self.pushButton_mapden_o.setObjectName("pushButton_mapden_o")
        self.splitter_32 = QtWidgets.QSplitter(self.mapden_tab)
        self.splitter_32.setGeometry(QtCore.QRect(20, 110, 161, 170))
        self.splitter_32.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_32.setMaximumSize(QtCore.QSize(161, 170))
        self.splitter_32.setOrientation(QtCore.Qt.Vertical)
        self.splitter_32.setObjectName("splitter_32")
        self.splitter_22 = QtWidgets.QSplitter(self.splitter_32)
        self.splitter_22.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_22.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_22.setObjectName("splitter_22")
        self.label_mapden_y = QtWidgets.QLabel(self.splitter_22)
        self.label_mapden_y.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_y.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_y.setObjectName("label_mapden_y")
        self.doubleSpinBox_mapden_y = QtWidgets.QDoubleSpinBox(self.splitter_22)
        self.doubleSpinBox_mapden_y.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_y.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_y.setDecimals(6)
        self.doubleSpinBox_mapden_y.setMinimum(0.0001)
        self.doubleSpinBox_mapden_y.setProperty("value", 8.0)
        self.doubleSpinBox_mapden_y.setObjectName("doubleSpinBox_mapden_y")
        self.splitter_20 = QtWidgets.QSplitter(self.splitter_32)
        self.splitter_20.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_20.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_20.setObjectName("splitter_20")
        self.label_mapden_x = QtWidgets.QLabel(self.splitter_20)
        self.label_mapden_x.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_x.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_x.setObjectName("label_mapden_x")
        self.doubleSpinBox_mapden_x = QtWidgets.QDoubleSpinBox(self.splitter_20)
        self.doubleSpinBox_mapden_x.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_x.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_x.setDecimals(6)
        self.doubleSpinBox_mapden_x.setMinimum(0.0001)
        self.doubleSpinBox_mapden_x.setProperty("value", 10.0)
        self.doubleSpinBox_mapden_x.setObjectName("doubleSpinBox_mapden_x")
        self.splitter_23 = QtWidgets.QSplitter(self.splitter_32)
        self.splitter_23.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_23.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_23.setObjectName("splitter_23")
        self.label_mapden_fs = QtWidgets.QLabel(self.splitter_23)
        self.label_mapden_fs.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_fs.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_fs.setObjectName("label_mapden_fs")
        self.doubleSpinBox_mapden_fs = QtWidgets.QDoubleSpinBox(self.splitter_23)
        self.doubleSpinBox_mapden_fs.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_fs.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_fs.setDecimals(6)
        self.doubleSpinBox_mapden_fs.setMinimum(0.0001)
        self.doubleSpinBox_mapden_fs.setProperty("value", 12.0)
        self.doubleSpinBox_mapden_fs.setObjectName("doubleSpinBox_mapden_fs")
        self.splitter_24 = QtWidgets.QSplitter(self.splitter_32)
        self.splitter_24.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_24.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_24.setObjectName("splitter_24")
        self.label_mapden_pad = QtWidgets.QLabel(self.splitter_24)
        self.label_mapden_pad.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_pad.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_pad.setObjectName("label_mapden_pad")
        self.doubleSpinBox_mapden_pad = QtWidgets.QDoubleSpinBox(self.splitter_24)
        self.doubleSpinBox_mapden_pad.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_pad.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_pad.setDecimals(3)
        self.doubleSpinBox_mapden_pad.setMinimum(0.0)
        self.doubleSpinBox_mapden_pad.setSingleStep(0.025)
        self.doubleSpinBox_mapden_pad.setProperty("value", 0.05)
        self.doubleSpinBox_mapden_pad.setObjectName("doubleSpinBox_mapden_pad")
        self.splitter_25 = QtWidgets.QSplitter(self.splitter_32)
        self.splitter_25.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_25.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_25.setObjectName("splitter_25")
        self.label_mapden_dpi = QtWidgets.QLabel(self.splitter_25)
        self.label_mapden_dpi.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_dpi.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_dpi.setObjectName("label_mapden_dpi")
        self.spinBox_mapden_dpi = QtWidgets.QSpinBox(self.splitter_25)
        self.spinBox_mapden_dpi.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_mapden_dpi.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_mapden_dpi.setMinimum(300)
        self.spinBox_mapden_dpi.setMaximum(5000)
        self.spinBox_mapden_dpi.setProperty("value", 300)
        self.spinBox_mapden_dpi.setObjectName("spinBox_mapden_dpi")
        self.splitter_30 = QtWidgets.QSplitter(self.splitter_32)
        self.splitter_30.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_30.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_30.setObjectName("splitter_30")
        self.label_mapden_b = QtWidgets.QLabel(self.splitter_30)
        self.label_mapden_b.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_b.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_b.setObjectName("label_mapden_b")
        self.doubleSpinBox_mapden_b = QtWidgets.QDoubleSpinBox(self.splitter_30)
        self.doubleSpinBox_mapden_b.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_b.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_b.setWrapping(False)
        self.doubleSpinBox_mapden_b.setDecimals(6)
        self.doubleSpinBox_mapden_b.setMinimum(1e-06)
        self.doubleSpinBox_mapden_b.setProperty("value", 1.0)
        self.doubleSpinBox_mapden_b.setObjectName("doubleSpinBox_mapden_b")
        self.splitter_31 = QtWidgets.QSplitter(self.splitter_32)
        self.splitter_31.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_31.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_31.setObjectName("splitter_31")
        self.label_3dpca_mapden_Chrfs = QtWidgets.QLabel(self.splitter_31)
        self.label_3dpca_mapden_Chrfs.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_mapden_Chrfs.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_mapden_Chrfs.setObjectName("label_3dpca_mapden_Chrfs")
        self.doubleSpinBox_mapden_Chrfs = QtWidgets.QDoubleSpinBox(self.splitter_31)
        self.doubleSpinBox_mapden_Chrfs.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_Chrfs.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_mapden_Chrfs.setDecimals(6)
        self.doubleSpinBox_mapden_Chrfs.setMinimum(0.0001)
        self.doubleSpinBox_mapden_Chrfs.setProperty("value", 8.0)
        self.doubleSpinBox_mapden_Chrfs.setObjectName("doubleSpinBox_mapden_Chrfs")
        self.splitter_125 = QtWidgets.QSplitter(self.mapden_tab)
        self.splitter_125.setGeometry(QtCore.QRect(190, 110, 161, 120))
        self.splitter_125.setMinimumSize(QtCore.QSize(161, 120))
        self.splitter_125.setMaximumSize(QtCore.QSize(161, 120))
        self.splitter_125.setOrientation(QtCore.Qt.Vertical)
        self.splitter_125.setObjectName("splitter_125")
        self.splitter_26 = QtWidgets.QSplitter(self.splitter_125)
        self.splitter_26.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_26.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_26.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_26.setObjectName("splitter_26")
        self.label_mapden_c = QtWidgets.QLabel(self.splitter_26)
        self.label_mapden_c.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_c.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_c.setObjectName("label_mapden_c")
        self.comboBox_mapden_c = QtWidgets.QComboBox(self.splitter_26)
        self.comboBox_mapden_c.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_mapden_c.setMaximumSize(QtCore.QSize(101, 101))
        self.comboBox_mapden_c.setEditable(True)
        self.comboBox_mapden_c.setMaxVisibleItems(20)
        self.comboBox_mapden_c.setObjectName("comboBox_mapden_c")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.comboBox_mapden_c.addItem("")
        self.splitter_27 = QtWidgets.QSplitter(self.splitter_125)
        self.splitter_27.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_27.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_27.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_27.setObjectName("splitter_27")
        self.label_mapden_ft = QtWidgets.QLabel(self.splitter_27)
        self.label_mapden_ft.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_ft.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_ft.setObjectName("label_mapden_ft")
        self.comboBox_mapden_ft = QtWidgets.QComboBox(self.splitter_27)
        self.comboBox_mapden_ft.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_mapden_ft.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_mapden_ft.setObjectName("comboBox_mapden_ft")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.comboBox_mapden_ft.addItem("")
        self.splitter_28 = QtWidgets.QSplitter(self.splitter_125)
        self.splitter_28.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_28.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_28.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_28.setObjectName("splitter_28")
        self.label_mapden_f = QtWidgets.QLabel(self.splitter_28)
        self.label_mapden_f.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_f.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_f.setObjectName("label_mapden_f")
        self.lineEdit_mapden_f = QtWidgets.QLineEdit(self.splitter_28)
        self.lineEdit_mapden_f.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_mapden_f.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_mapden_f.setObjectName("lineEdit_mapden_f")
        self.splitter_29 = QtWidgets.QSplitter(self.splitter_125)
        self.splitter_29.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_29.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_29.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_29.setObjectName("splitter_29")
        self.label_mapden_chr = QtWidgets.QLabel(self.splitter_29)
        self.label_mapden_chr.setMinimumSize(QtCore.QSize(31, 20))
        self.label_mapden_chr.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_chr.setObjectName("label_mapden_chr")
        self.lineEdit_mapden_chr = QtWidgets.QLineEdit(self.splitter_29)
        self.lineEdit_mapden_chr.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_mapden_chr.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_mapden_chr.setSizeIncrement(QtCore.QSize(0, 0))
        self.lineEdit_mapden_chr.setObjectName("lineEdit_mapden_chr")
        self.splitter_33 = QtWidgets.QSplitter(self.splitter_125)
        self.splitter_33.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_33.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_33.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_33.setObjectName("splitter_33")
        self.label_mapden_mode = QtWidgets.QLabel(self.splitter_33)
        self.label_mapden_mode.setMinimumSize(QtCore.QSize(55, 20))
        self.label_mapden_mode.setMaximumSize(QtCore.QSize(55, 20))
        self.label_mapden_mode.setObjectName("label_mapden_mode")
        self.comboBox_mapden_mode = QtWidgets.QComboBox(self.splitter_33)
        self.comboBox_mapden_mode.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_mapden_mode.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_mapden_mode.setObjectName("comboBox_mapden_mode")
        self.comboBox_mapden_mode.addItem("")
        self.comboBox_mapden_mode.addItem("")
        self.tabWidget.addTab(self.mapden_tab, "")
        self.relmap_tab = QtWidgets.QWidget()
        self.relmap_tab.setObjectName("relmap_tab")
        self.pushButton_relmap_run = QtWidgets.QPushButton(self.relmap_tab)
        self.pushButton_relmap_run.setGeometry(QtCore.QRect(20, 350, 661, 30))
        self.pushButton_relmap_run.setMinimumSize(QtCore.QSize(650, 30))
        self.pushButton_relmap_run.setObjectName("pushButton_relmap_run")
        self.splitter_34 = QtWidgets.QSplitter(self.relmap_tab)
        self.splitter_34.setGeometry(QtCore.QRect(20, 11, 664, 80))
        self.splitter_34.setMinimumSize(QtCore.QSize(664, 80))
        self.splitter_34.setMaximumSize(QtCore.QSize(641, 70))
        self.splitter_34.setOrientation(QtCore.Qt.Vertical)
        self.splitter_34.setObjectName("splitter_34")
        self.splitter = QtWidgets.QSplitter(self.splitter_34)
        self.splitter.setMinimumSize(QtCore.QSize(641, 21))
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.label__relmap_relfile = QtWidgets.QLabel(self.splitter)
        self.label__relmap_relfile.setMinimumSize(QtCore.QSize(62, 20))
        self.label__relmap_relfile.setMaximumSize(QtCore.QSize(62, 20))
        self.label__relmap_relfile.setObjectName("label__relmap_relfile")
        self.lineEdit__relmap_relfile = QtWidgets.QLineEdit(self.splitter)
        self.lineEdit__relmap_relfile.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit__relmap_relfile.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit__relmap_relfile.setMouseTracking(True)
        self.lineEdit__relmap_relfile.setObjectName("lineEdit__relmap_relfile")
        self.pushButton__relmap_relfile = QtWidgets.QPushButton(self.splitter)
        self.pushButton__relmap_relfile.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton__relmap_relfile.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton__relmap_relfile.setAutoDefault(False)
        self.pushButton__relmap_relfile.setObjectName("pushButton__relmap_relfile")
        self.splitter_4 = QtWidgets.QSplitter(self.splitter_34)
        self.splitter_4.setMinimumSize(QtCore.QSize(641, 21))
        self.splitter_4.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_4.setObjectName("splitter_4")
        self.label_relmap_matindex = QtWidgets.QLabel(self.splitter_4)
        self.label_relmap_matindex.setMinimumSize(QtCore.QSize(62, 20))
        self.label_relmap_matindex.setMaximumSize(QtCore.QSize(62, 20))
        self.label_relmap_matindex.setObjectName("label_relmap_matindex")
        self.lineEdit_relmap_matindex = QtWidgets.QLineEdit(self.splitter_4)
        self.lineEdit_relmap_matindex.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_relmap_matindex.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_relmap_matindex.setObjectName("lineEdit_relmap_matindex")
        self.pushButton_relmap_matindex = QtWidgets.QPushButton(self.splitter_4)
        self.pushButton_relmap_matindex.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_relmap_matindex.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_relmap_matindex.setAutoDefault(False)
        self.pushButton_relmap_matindex.setFlat(False)
        self.pushButton_relmap_matindex.setObjectName("pushButton_relmap_matindex")
        self.splitter_17 = QtWidgets.QSplitter(self.splitter_34)
        self.splitter_17.setMinimumSize(QtCore.QSize(641, 21))
        self.splitter_17.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_17.setObjectName("splitter_17")
        self.label_relmap_o = QtWidgets.QLabel(self.splitter_17)
        self.label_relmap_o.setMinimumSize(QtCore.QSize(52, 20))
        self.label_relmap_o.setMaximumSize(QtCore.QSize(52, 20))
        self.label_relmap_o.setObjectName("label_relmap_o")
        self.lineEdit_relmap_o = QtWidgets.QLineEdit(self.splitter_17)
        self.lineEdit_relmap_o.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_relmap_o.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_relmap_o.setObjectName("lineEdit_relmap_o")
        self.pushButton_relmap_o = QtWidgets.QPushButton(self.splitter_17)
        self.pushButton_relmap_o.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_relmap_o.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_relmap_o.setAutoDefault(False)
        self.pushButton_relmap_o.setObjectName("pushButton_relmap_o")
        self.splitter_50 = QtWidgets.QSplitter(self.relmap_tab)
        self.splitter_50.setGeometry(QtCore.QRect(20, 110, 161, 170))
        self.splitter_50.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_50.setMaximumSize(QtCore.QSize(161, 170))
        self.splitter_50.setOrientation(QtCore.Qt.Vertical)
        self.splitter_50.setObjectName("splitter_50")
        self.splitter_43 = QtWidgets.QSplitter(self.splitter_50)
        self.splitter_43.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_43.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_43.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_43.setObjectName("splitter_43")
        self.label_relmap_rf = QtWidgets.QLabel(self.splitter_43)
        self.label_relmap_rf.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_rf.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_rf.setObjectName("label_relmap_rf")
        self.comboBox_relmap_rf = QtWidgets.QComboBox(self.splitter_43)
        self.comboBox_relmap_rf.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_rf.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_rf.setModelColumn(0)
        self.comboBox_relmap_rf.setObjectName("comboBox_relmap_rf")
        self.comboBox_relmap_rf.addItem("")
        self.comboBox_relmap_rf.addItem("")
        self.splitter_44 = QtWidgets.QSplitter(self.splitter_50)
        self.splitter_44.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_44.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_44.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_44.setObjectName("splitter_44")
        self.label_relmap_av = QtWidgets.QLabel(self.splitter_44)
        self.label_relmap_av.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_av.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_av.setObjectName("label_relmap_av")
        self.comboBox_relmap_av = QtWidgets.QComboBox(self.splitter_44)
        self.comboBox_relmap_av.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_av.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_av.setObjectName("comboBox_relmap_av")
        self.comboBox_relmap_av.addItem("")
        self.comboBox_relmap_av.addItem("")
        self.splitter_45 = QtWidgets.QSplitter(self.splitter_50)
        self.splitter_45.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_45.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_45.setObjectName("splitter_45")
        self.label_relmap_mask = QtWidgets.QLabel(self.splitter_45)
        self.label_relmap_mask.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_mask.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_mask.setObjectName("label_relmap_mask")
        self.comboBox_relmap_mask = QtWidgets.QComboBox(self.splitter_45)
        self.comboBox_relmap_mask.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_mask.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_mask.setObjectName("comboBox_relmap_mask")
        self.comboBox_relmap_mask.addItem("")
        self.comboBox_relmap_mask.addItem("")
        self.splitter_46 = QtWidgets.QSplitter(self.splitter_50)
        self.splitter_46.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_46.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_46.setObjectName("splitter_46")
        self.label_relmap_a = QtWidgets.QLabel(self.splitter_46)
        self.label_relmap_a.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_a.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_a.setObjectName("label_relmap_a")
        self.comboBox_relmap_a = QtWidgets.QComboBox(self.splitter_46)
        self.comboBox_relmap_a.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_a.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_a.setObjectName("comboBox_relmap_a")
        self.comboBox_relmap_a.addItem("")
        self.comboBox_relmap_a.addItem("")
        self.splitter_47 = QtWidgets.QSplitter(self.splitter_50)
        self.splitter_47.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_47.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_47.setObjectName("splitter_47")
        self.label_relmap_sl = QtWidgets.QLabel(self.splitter_47)
        self.label_relmap_sl.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_sl.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_sl.setObjectName("label_relmap_sl")
        self.comboBox_relmap_sl = QtWidgets.QComboBox(self.splitter_47)
        self.comboBox_relmap_sl.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_sl.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_sl.setObjectName("comboBox_relmap_sl")
        self.comboBox_relmap_sl.addItem("")
        self.comboBox_relmap_sl.addItem("")
        self.splitter_48 = QtWidgets.QSplitter(self.splitter_50)
        self.splitter_48.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_48.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_48.setObjectName("splitter_48")
        self.label_relmap_lc = QtWidgets.QLabel(self.splitter_48)
        self.label_relmap_lc.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_lc.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_lc.setObjectName("label_relmap_lc")
        self.lineEdit_relmap_lc = QtWidgets.QLineEdit(self.splitter_48)
        self.lineEdit_relmap_lc.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_relmap_lc.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_relmap_lc.setObjectName("lineEdit_relmap_lc")
        self.splitter_49 = QtWidgets.QSplitter(self.splitter_50)
        self.splitter_49.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_49.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_49.setObjectName("splitter_49")
        self.label_relmap_t = QtWidgets.QLabel(self.splitter_49)
        self.label_relmap_t.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_t.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_t.setObjectName("label_relmap_t")
        self.lineEdit_relmap_t = QtWidgets.QLineEdit(self.splitter_49)
        self.lineEdit_relmap_t.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_relmap_t.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_relmap_t.setObjectName("lineEdit_relmap_t")
        self.splitter_42 = QtWidgets.QSplitter(self.relmap_tab)
        self.splitter_42.setGeometry(QtCore.QRect(190, 110, 161, 170))
        self.splitter_42.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_42.setMaximumSize(QtCore.QSize(161, 170))
        self.splitter_42.setOrientation(QtCore.Qt.Vertical)
        self.splitter_42.setObjectName("splitter_42")
        self.splitter_39 = QtWidgets.QSplitter(self.splitter_42)
        self.splitter_39.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_39.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_39.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_39.setObjectName("splitter_39")
        self.label_relmap_x = QtWidgets.QLabel(self.splitter_39)
        self.label_relmap_x.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_x.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_x.setObjectName("label_relmap_x")
        self.doubleSpinBox_relmap_x = QtWidgets.QDoubleSpinBox(self.splitter_39)
        self.doubleSpinBox_relmap_x.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_x.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_x.setDecimals(6)
        self.doubleSpinBox_relmap_x.setMinimum(0.0001)
        self.doubleSpinBox_relmap_x.setProperty("value", 14.0)
        self.doubleSpinBox_relmap_x.setObjectName("doubleSpinBox_relmap_x")
        self.splitter_38 = QtWidgets.QSplitter(self.splitter_42)
        self.splitter_38.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_38.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_38.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_38.setObjectName("splitter_38")
        self.label_relmap_y = QtWidgets.QLabel(self.splitter_38)
        self.label_relmap_y.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_y.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_y.setObjectName("label_relmap_y")
        self.doubleSpinBox_relmap_y = QtWidgets.QDoubleSpinBox(self.splitter_38)
        self.doubleSpinBox_relmap_y.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_y.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_y.setFrame(True)
        self.doubleSpinBox_relmap_y.setDecimals(6)
        self.doubleSpinBox_relmap_y.setMinimum(0.0001)
        self.doubleSpinBox_relmap_y.setProperty("value", 10.0)
        self.doubleSpinBox_relmap_y.setObjectName("doubleSpinBox_relmap_y")
        self.splitter_3 = QtWidgets.QSplitter(self.splitter_42)
        self.splitter_3.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_3.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_3.setObjectName("splitter_3")
        self.label_relmap_pfs = QtWidgets.QLabel(self.splitter_3)
        self.label_relmap_pfs.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_pfs.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_pfs.setObjectName("label_relmap_pfs")
        self.doubleSpinBox_relmap_pfs = QtWidgets.QDoubleSpinBox(self.splitter_3)
        self.doubleSpinBox_relmap_pfs.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_pfs.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_pfs.setDecimals(6)
        self.doubleSpinBox_relmap_pfs.setMinimum(0.0001)
        self.doubleSpinBox_relmap_pfs.setProperty("value", 12.0)
        self.doubleSpinBox_relmap_pfs.setObjectName("doubleSpinBox_relmap_pfs")
        self.splitter_35 = QtWidgets.QSplitter(self.splitter_42)
        self.splitter_35.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_35.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_35.setObjectName("splitter_35")
        self.label_relmap_xyfs = QtWidgets.QLabel(self.splitter_35)
        self.label_relmap_xyfs.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_xyfs.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_xyfs.setObjectName("label_relmap_xyfs")
        self.doubleSpinBox_relmap_xyfs = QtWidgets.QDoubleSpinBox(self.splitter_35)
        self.doubleSpinBox_relmap_xyfs.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_xyfs.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_xyfs.setDecimals(6)
        self.doubleSpinBox_relmap_xyfs.setMinimum(0.0001)
        self.doubleSpinBox_relmap_xyfs.setProperty("value", 1.0)
        self.doubleSpinBox_relmap_xyfs.setObjectName("doubleSpinBox_relmap_xyfs")
        self.splitter_36 = QtWidgets.QSplitter(self.splitter_42)
        self.splitter_36.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_36.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_36.setObjectName("splitter_36")
        self.label_relmap_lws = QtWidgets.QLabel(self.splitter_36)
        self.label_relmap_lws.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_lws.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_lws.setObjectName("label_relmap_lws")
        self.doubleSpinBox_relmap_lws = QtWidgets.QDoubleSpinBox(self.splitter_36)
        self.doubleSpinBox_relmap_lws.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_lws.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_lws.setDecimals(7)
        self.doubleSpinBox_relmap_lws.setMinimum(1e-06)
        self.doubleSpinBox_relmap_lws.setSingleStep(1.0)
        self.doubleSpinBox_relmap_lws.setProperty("value", 0.45)
        self.doubleSpinBox_relmap_lws.setObjectName("doubleSpinBox_relmap_lws")
        self.splitter_37 = QtWidgets.QSplitter(self.splitter_42)
        self.splitter_37.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_37.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_37.setObjectName("splitter_37")
        self.label_relmap_afs = QtWidgets.QLabel(self.splitter_37)
        self.label_relmap_afs.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_afs.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_afs.setObjectName("label_relmap_afs")
        self.doubleSpinBox_relmap_afs = QtWidgets.QDoubleSpinBox(self.splitter_37)
        self.doubleSpinBox_relmap_afs.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_afs.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_relmap_afs.setDecimals(6)
        self.doubleSpinBox_relmap_afs.setMinimum(0.0001)
        self.doubleSpinBox_relmap_afs.setProperty("value", 1.0)
        self.doubleSpinBox_relmap_afs.setObjectName("doubleSpinBox_relmap_afs")
        self.splitter_41 = QtWidgets.QSplitter(self.splitter_42)
        self.splitter_41.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_41.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_41.setObjectName("splitter_41")
        self.label_relmap_dpi = QtWidgets.QLabel(self.splitter_41)
        self.label_relmap_dpi.setMinimumSize(QtCore.QSize(20, 20))
        self.label_relmap_dpi.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_dpi.setObjectName("label_relmap_dpi")
        self.spinBox_relmap_dpi = QtWidgets.QSpinBox(self.splitter_41)
        self.spinBox_relmap_dpi.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_relmap_dpi.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_relmap_dpi.setMinimum(300)
        self.spinBox_relmap_dpi.setMaximum(5000)
        self.spinBox_relmap_dpi.setProperty("value", 300)
        self.spinBox_relmap_dpi.setObjectName("spinBox_relmap_dpi")
        self.splitter_126 = QtWidgets.QSplitter(self.relmap_tab)
        self.splitter_126.setGeometry(QtCore.QRect(360, 110, 161, 97))
        self.splitter_126.setMinimumSize(QtCore.QSize(161, 97))
        self.splitter_126.setOrientation(QtCore.Qt.Vertical)
        self.splitter_126.setObjectName("splitter_126")
        self.splitter_51 = QtWidgets.QSplitter(self.splitter_126)
        self.splitter_51.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_51.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_51.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_51.setObjectName("splitter_51")
        self.label_relmap_ft = QtWidgets.QLabel(self.splitter_51)
        self.label_relmap_ft.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_ft.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_ft.setObjectName("label_relmap_ft")
        self.comboBox_relmap_ft = QtWidgets.QComboBox(self.splitter_51)
        self.comboBox_relmap_ft.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_ft.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_ft.setObjectName("comboBox_relmap_ft")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.comboBox_relmap_ft.addItem("")
        self.splitter_40 = QtWidgets.QSplitter(self.splitter_126)
        self.splitter_40.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_40.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_40.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_40.setObjectName("splitter_40")
        self.label_relmap_c = QtWidgets.QLabel(self.splitter_40)
        self.label_relmap_c.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_c.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_c.setObjectName("label_relmap_c")
        self.comboBox_relmap_c = QtWidgets.QComboBox(self.splitter_40)
        self.comboBox_relmap_c.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_c.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_c.setEditable(True)
        self.comboBox_relmap_c.setMaxVisibleItems(20)
        self.comboBox_relmap_c.setMaxCount(2147483644)
        self.comboBox_relmap_c.setObjectName("comboBox_relmap_c")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.comboBox_relmap_c.addItem("")
        self.splitter_52 = QtWidgets.QSplitter(self.splitter_126)
        self.splitter_52.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_52.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_52.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_52.setObjectName("splitter_52")
        self.label_relmap_f = QtWidgets.QLabel(self.splitter_52)
        self.label_relmap_f.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_f.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_f.setObjectName("label_relmap_f")
        self.lineEdit_relmap_f = QtWidgets.QLineEdit(self.splitter_52)
        self.lineEdit_relmap_f.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_relmap_f.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_relmap_f.setObjectName("lineEdit_relmap_f")
        self.splitter_53 = QtWidgets.QSplitter(self.splitter_126)
        self.splitter_53.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_53.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_53.setObjectName("splitter_53")
        self.label_relmap_mode = QtWidgets.QLabel(self.splitter_53)
        self.label_relmap_mode.setMinimumSize(QtCore.QSize(55, 20))
        self.label_relmap_mode.setMaximumSize(QtCore.QSize(55, 20))
        self.label_relmap_mode.setObjectName("label_relmap_mode")
        self.comboBox_relmap_mode = QtWidgets.QComboBox(self.splitter_53)
        self.comboBox_relmap_mode.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_mode.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_relmap_mode.setObjectName("comboBox_relmap_mode")
        self.comboBox_relmap_mode.addItem("")
        self.comboBox_relmap_mode.addItem("")
        self.tabWidget.addTab(self.relmap_tab, "")
        self.pca_tab = QtWidgets.QWidget()
        self.pca_tab.setObjectName("pca_tab")
        self.pushButton_3dpca_RUN = QtWidgets.QPushButton(self.pca_tab)
        self.pushButton_3dpca_RUN.setGeometry(QtCore.QRect(20, 350, 661, 30))
        self.pushButton_3dpca_RUN.setMinimumSize(QtCore.QSize(661, 30))
        self.pushButton_3dpca_RUN.setMaximumSize(QtCore.QSize(661, 30))
        self.pushButton_3dpca_RUN.setObjectName("pushButton_3dpca_RUN")
        self.splitter_16 = QtWidgets.QSplitter(self.pca_tab)
        self.splitter_16.setGeometry(QtCore.QRect(20, 11, 664, 80))
        self.splitter_16.setMinimumSize(QtCore.QSize(664, 80))
        self.splitter_16.setMaximumSize(QtCore.QSize(641, 70))
        self.splitter_16.setOrientation(QtCore.Qt.Vertical)
        self.splitter_16.setObjectName("splitter_16")
        self.splitter_9 = QtWidgets.QSplitter(self.splitter_16)
        self.splitter_9.setMinimumSize(QtCore.QSize(641, 20))
        self.splitter_9.setMaximumSize(QtCore.QSize(597, 20))
        self.splitter_9.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_9.setObjectName("splitter_9")
        self.label_3dpca_evec = QtWidgets.QLabel(self.splitter_9)
        self.label_3dpca_evec.setMinimumSize(QtCore.QSize(62, 20))
        self.label_3dpca_evec.setMaximumSize(QtCore.QSize(62, 20))
        self.label_3dpca_evec.setObjectName("label_3dpca_evec")
        self.lineEdit_3dpca_evec = QtWidgets.QLineEdit(self.splitter_9)
        self.lineEdit_3dpca_evec.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_3dpca_evec.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_3dpca_evec.setObjectName("lineEdit_3dpca_evec")
        self.pushButton_3dpca_evec = QtWidgets.QPushButton(self.splitter_9)
        self.pushButton_3dpca_evec.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_3dpca_evec.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_3dpca_evec.setAutoDefault(False)
        self.pushButton_3dpca_evec.setObjectName("pushButton_3dpca_evec")
        self.splitter_14 = QtWidgets.QSplitter(self.splitter_16)
        self.splitter_14.setMinimumSize(QtCore.QSize(641, 20))
        self.splitter_14.setMaximumSize(QtCore.QSize(597, 20))
        self.splitter_14.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_14.setObjectName("splitter_14")
        self.label_3dpca_eval = QtWidgets.QLabel(self.splitter_14)
        self.label_3dpca_eval.setMinimumSize(QtCore.QSize(62, 20))
        self.label_3dpca_eval.setMaximumSize(QtCore.QSize(62, 20))
        self.label_3dpca_eval.setObjectName("label_3dpca_eval")
        self.lineEdit_3dpca_eval = QtWidgets.QLineEdit(self.splitter_14)
        self.lineEdit_3dpca_eval.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_3dpca_eval.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_3dpca_eval.setText("")
        self.lineEdit_3dpca_eval.setObjectName("lineEdit_3dpca_eval")
        self.pushButton_3dpca_eval = QtWidgets.QPushButton(self.splitter_14)
        self.pushButton_3dpca_eval.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_3dpca_eval.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_3dpca_eval.setAutoDefault(False)
        self.pushButton_3dpca_eval.setFlat(False)
        self.pushButton_3dpca_eval.setObjectName("pushButton_3dpca_eval")
        self.splitter_15 = QtWidgets.QSplitter(self.splitter_16)
        self.splitter_15.setMinimumSize(QtCore.QSize(641, 20))
        self.splitter_15.setMaximumSize(QtCore.QSize(597, 20))
        self.splitter_15.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_15.setObjectName("splitter_15")
        self.label_3dpca_o = QtWidgets.QLabel(self.splitter_15)
        self.label_3dpca_o.setMinimumSize(QtCore.QSize(62, 20))
        self.label_3dpca_o.setMaximumSize(QtCore.QSize(62, 20))
        self.label_3dpca_o.setObjectName("label_3dpca_o")
        self.lineEdit_3dpca_o = QtWidgets.QLineEdit(self.splitter_15)
        self.lineEdit_3dpca_o.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_3dpca_o.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_3dpca_o.setObjectName("lineEdit_3dpca_o")
        self.pushButton_3dpca_o = QtWidgets.QPushButton(self.splitter_15)
        self.pushButton_3dpca_o.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_3dpca_o.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_3dpca_o.setAutoDefault(False)
        self.pushButton_3dpca_o.setObjectName("pushButton_3dpca_o")
        self.splitter_64 = QtWidgets.QSplitter(self.pca_tab)
        self.splitter_64.setGeometry(QtCore.QRect(190, 110, 161, 170))
        self.splitter_64.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_64.setMaximumSize(QtCore.QSize(161, 170))
        self.splitter_64.setOrientation(QtCore.Qt.Vertical)
        self.splitter_64.setObjectName("splitter_64")
        self.splitter_54 = QtWidgets.QSplitter(self.splitter_64)
        self.splitter_54.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_54.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_54.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_54.setObjectName("splitter_54")
        self.label_3dpca_fp = QtWidgets.QLabel(self.splitter_54)
        self.label_3dpca_fp.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_fp.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_fp.setObjectName("label_3dpca_fp")
        self.spinBox_3dpca_fp = QtWidgets.QSpinBox(self.splitter_54)
        self.spinBox_3dpca_fp.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_3dpca_fp.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_3dpca_fp.setProperty("value", 1)
        self.spinBox_3dpca_fp.setDisplayIntegerBase(10)
        self.spinBox_3dpca_fp.setObjectName("spinBox_3dpca_fp")
        self.splitter_55 = QtWidgets.QSplitter(self.splitter_64)
        self.splitter_55.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_55.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_55.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_55.setObjectName("splitter_55")
        self.label_3dpca_sp = QtWidgets.QLabel(self.splitter_55)
        self.label_3dpca_sp.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_sp.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_sp.setObjectName("label_3dpca_sp")
        self.spinBox_3dpca_sp = QtWidgets.QSpinBox(self.splitter_55)
        self.spinBox_3dpca_sp.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_3dpca_sp.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_3dpca_sp.setProperty("value", 2)
        self.spinBox_3dpca_sp.setObjectName("spinBox_3dpca_sp")
        self.splitter_56 = QtWidgets.QSplitter(self.splitter_64)
        self.splitter_56.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_56.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_56.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_56.setObjectName("splitter_56")
        self.label_3dpca_tp = QtWidgets.QLabel(self.splitter_56)
        self.label_3dpca_tp.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_tp.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_tp.setObjectName("label_3dpca_tp")
        self.spinBox_3dpca_tp = QtWidgets.QSpinBox(self.splitter_56)
        self.spinBox_3dpca_tp.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_3dpca_tp.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_3dpca_tp.setProperty("value", 3)
        self.spinBox_3dpca_tp.setObjectName("spinBox_3dpca_tp")
        self.splitter_61 = QtWidgets.QSplitter(self.splitter_64)
        self.splitter_61.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_61.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_61.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_61.setObjectName("splitter_61")
        self.label_3dpca_s = QtWidgets.QLabel(self.splitter_61)
        self.label_3dpca_s.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_s.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_s.setObjectName("label_3dpca_s")
        self.doubleSpinBox_3dpca_s = QtWidgets.QDoubleSpinBox(self.splitter_61)
        self.doubleSpinBox_3dpca_s.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_s.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_s.setDecimals(1)
        self.doubleSpinBox_3dpca_s.setMinimum(0.1)
        self.doubleSpinBox_3dpca_s.setMaximum(200.0)
        self.doubleSpinBox_3dpca_s.setSingleStep(10.0)
        self.doubleSpinBox_3dpca_s.setProperty("value", 40.0)
        self.doubleSpinBox_3dpca_s.setObjectName("doubleSpinBox_3dpca_s")
        self.splitter_63 = QtWidgets.QSplitter(self.splitter_64)
        self.splitter_63.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_63.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_63.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_63.setObjectName("splitter_63")
        self.label_3dpca_c = QtWidgets.QLabel(self.splitter_63)
        self.label_3dpca_c.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_c.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_c.setObjectName("label_3dpca_c")
        self.comboBox_3dpca_c = QtWidgets.QComboBox(self.splitter_63)
        self.comboBox_3dpca_c.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_3dpca_c.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_3dpca_c.setEditable(True)
        self.comboBox_3dpca_c.setMaxVisibleItems(20)
        self.comboBox_3dpca_c.setObjectName("comboBox_3dpca_c")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.comboBox_3dpca_c.addItem("")
        self.splitter_59 = QtWidgets.QSplitter(self.splitter_64)
        self.splitter_59.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_59.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_59.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_59.setObjectName("splitter_59")
        self.label_3dpca_x = QtWidgets.QLabel(self.splitter_59)
        self.label_3dpca_x.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_x.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_x.setObjectName("label_3dpca_x")
        self.doubleSpinBox_3dpca_x = QtWidgets.QDoubleSpinBox(self.splitter_59)
        self.doubleSpinBox_3dpca_x.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_x.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_x.setDecimals(6)
        self.doubleSpinBox_3dpca_x.setMinimum(0.0001)
        self.doubleSpinBox_3dpca_x.setProperty("value", 10.0)
        self.doubleSpinBox_3dpca_x.setObjectName("doubleSpinBox_3dpca_x")
        self.splitter_60 = QtWidgets.QSplitter(self.splitter_64)
        self.splitter_60.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_60.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_60.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_60.setObjectName("splitter_60")
        self.label_3dpca_y = QtWidgets.QLabel(self.splitter_60)
        self.label_3dpca_y.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_y.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_y.setObjectName("label_3dpca_y")
        self.doubleSpinBox_3dpca_y = QtWidgets.QDoubleSpinBox(self.splitter_60)
        self.doubleSpinBox_3dpca_y.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_y.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_y.setDecimals(6)
        self.doubleSpinBox_3dpca_y.setMinimum(0.0001)
        self.doubleSpinBox_3dpca_y.setProperty("value", 5.0)
        self.doubleSpinBox_3dpca_y.setObjectName("doubleSpinBox_3dpca_y")
        self.splitter_69 = QtWidgets.QSplitter(self.pca_tab)
        self.splitter_69.setGeometry(QtCore.QRect(20, 110, 161, 170))
        self.splitter_69.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_69.setMaximumSize(QtCore.QSize(161, 170))
        self.splitter_69.setOrientation(QtCore.Qt.Vertical)
        self.splitter_69.setObjectName("splitter_69")
        self.splitter_66 = QtWidgets.QSplitter(self.splitter_69)
        self.splitter_66.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_66.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_66.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_66.setObjectName("splitter_66")
        self.label_3dpca_mode = QtWidgets.QLabel(self.splitter_66)
        self.label_3dpca_mode.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_mode.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_mode.setObjectName("label_3dpca_mode")
        self.comboBox_3dpca_mode = QtWidgets.QComboBox(self.splitter_66)
        self.comboBox_3dpca_mode.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_3dpca_mode.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_3dpca_mode.setObjectName("comboBox_3dpca_mode")
        self.comboBox_3dpca_mode.addItem("")
        self.comboBox_3dpca_mode.addItem("")
        self.splitter_57 = QtWidgets.QSplitter(self.splitter_69)
        self.splitter_57.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_57.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_57.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_57.setObjectName("splitter_57")
        self.label_3dpca_azim = QtWidgets.QLabel(self.splitter_57)
        self.label_3dpca_azim.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_azim.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_azim.setObjectName("label_3dpca_azim")
        self.doubleSpinBox_3dpca_azim = QtWidgets.QDoubleSpinBox(self.splitter_57)
        self.doubleSpinBox_3dpca_azim.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_azim.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_azim.setDecimals(1)
        self.doubleSpinBox_3dpca_azim.setMinimum(-360.0)
        self.doubleSpinBox_3dpca_azim.setMaximum(360.0)
        self.doubleSpinBox_3dpca_azim.setSingleStep(10.0)
        self.doubleSpinBox_3dpca_azim.setProperty("value", 65.0)
        self.doubleSpinBox_3dpca_azim.setObjectName("doubleSpinBox_3dpca_azim")
        self.splitter_58 = QtWidgets.QSplitter(self.splitter_69)
        self.splitter_58.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_58.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_58.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_58.setObjectName("splitter_58")
        self.label_3dpca_elev = QtWidgets.QLabel(self.splitter_58)
        self.label_3dpca_elev.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_elev.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_elev.setObjectName("label_3dpca_elev")
        self.doubleSpinBox_3dpca_elev = QtWidgets.QDoubleSpinBox(self.splitter_58)
        self.doubleSpinBox_3dpca_elev.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_elev.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_elev.setDecimals(1)
        self.doubleSpinBox_3dpca_elev.setMinimum(-360.0)
        self.doubleSpinBox_3dpca_elev.setMaximum(360.0)
        self.doubleSpinBox_3dpca_elev.setSingleStep(10.0)
        self.doubleSpinBox_3dpca_elev.setProperty("value", 20.0)
        self.doubleSpinBox_3dpca_elev.setObjectName("doubleSpinBox_3dpca_elev")
        self.splitter_62 = QtWidgets.QSplitter(self.splitter_69)
        self.splitter_62.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_62.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_62.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_62.setObjectName("splitter_62")
        self.label_3dpca_fs = QtWidgets.QLabel(self.splitter_62)
        self.label_3dpca_fs.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_fs.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_fs.setObjectName("label_3dpca_fs")
        self.doubleSpinBox_3dpca_fs = QtWidgets.QDoubleSpinBox(self.splitter_62)
        self.doubleSpinBox_3dpca_fs.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_fs.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_3dpca_fs.setDecimals(6)
        self.doubleSpinBox_3dpca_fs.setMinimum(0.0001)
        self.doubleSpinBox_3dpca_fs.setProperty("value", 10.0)
        self.doubleSpinBox_3dpca_fs.setObjectName("doubleSpinBox_3dpca_fs")
        self.splitter_67 = QtWidgets.QSplitter(self.splitter_69)
        self.splitter_67.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_67.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_67.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_67.setObjectName("splitter_67")
        self.label_3dpca_f = QtWidgets.QLabel(self.splitter_67)
        self.label_3dpca_f.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_f.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_f.setObjectName("label_3dpca_f")
        self.lineEdit_3dpca_f = QtWidgets.QLineEdit(self.splitter_67)
        self.lineEdit_3dpca_f.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_3dpca_f.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_3dpca_f.setObjectName("lineEdit_3dpca_f")
        self.splitter_65 = QtWidgets.QSplitter(self.splitter_69)
        self.splitter_65.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_65.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_65.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_65.setObjectName("splitter_65")
        self.label_3dpca_dpi = QtWidgets.QLabel(self.splitter_65)
        self.label_3dpca_dpi.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_dpi.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_dpi.setObjectName("label_3dpca_dpi")
        self.spinBox_3dpca_dpi = QtWidgets.QSpinBox(self.splitter_65)
        self.spinBox_3dpca_dpi.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_3dpca_dpi.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_3dpca_dpi.setMinimum(300)
        self.spinBox_3dpca_dpi.setMaximum(5000)
        self.spinBox_3dpca_dpi.setProperty("value", 300)
        self.spinBox_3dpca_dpi.setObjectName("spinBox_3dpca_dpi")
        self.splitter_68 = QtWidgets.QSplitter(self.splitter_69)
        self.splitter_68.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_68.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_68.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_68.setObjectName("splitter_68")
        self.label_3dpca_ft = QtWidgets.QLabel(self.splitter_68)
        self.label_3dpca_ft.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_ft.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_ft.setObjectName("label_3dpca_ft")
        self.comboBox_3dpca_ft = QtWidgets.QComboBox(self.splitter_68)
        self.comboBox_3dpca_ft.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_3dpca_ft.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_3dpca_ft.setObjectName("comboBox_3dpca_ft")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.comboBox_3dpca_ft.addItem("")
        self.splitter_131 = QtWidgets.QSplitter(self.pca_tab)
        self.splitter_131.setGeometry(QtCore.QRect(380, 110, 161, 20))
        self.splitter_131.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_131.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_131.setObjectName("splitter_131")
        self.label_3dpca_dim = QtWidgets.QLabel(self.splitter_131)
        self.label_3dpca_dim.setMinimumSize(QtCore.QSize(55, 20))
        self.label_3dpca_dim.setMaximumSize(QtCore.QSize(55, 20))
        self.label_3dpca_dim.setObjectName("label_3dpca_dim")
        self.comboBox_3dpca_dim = QtWidgets.QComboBox(self.splitter_131)
        self.comboBox_3dpca_dim.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_3dpca_dim.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_3dpca_dim.setObjectName("comboBox_3dpca_dim")
        self.comboBox_3dpca_dim.addItem("")
        self.comboBox_3dpca_dim.addItem("")
        self.tabWidget.addTab(self.pca_tab, "")
        self.admix_tab = QtWidgets.QWidget()
        self.admix_tab.setObjectName("admix_tab")
        self.pushButton_admix_RUN = QtWidgets.QPushButton(self.admix_tab)
        self.pushButton_admix_RUN.setGeometry(QtCore.QRect(20, 350, 661, 30))
        self.pushButton_admix_RUN.setMinimumSize(QtCore.QSize(661, 30))
        self.pushButton_admix_RUN.setMaximumSize(QtCore.QSize(661, 30))
        self.pushButton_admix_RUN.setObjectName("pushButton_admix_RUN")
        self.splitter_70 = QtWidgets.QSplitter(self.admix_tab)
        self.splitter_70.setGeometry(QtCore.QRect(20, 11, 646, 45))
        self.splitter_70.setOrientation(QtCore.Qt.Vertical)
        self.splitter_70.setObjectName("splitter_70")
        self.splitter_13 = QtWidgets.QSplitter(self.splitter_70)
        self.splitter_13.setMinimumSize(QtCore.QSize(646, 20))
        self.splitter_13.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_13.setObjectName("splitter_13")
        self.label_admix_d = QtWidgets.QLabel(self.splitter_13)
        self.label_admix_d.setMinimumSize(QtCore.QSize(62, 20))
        self.label_admix_d.setMaximumSize(QtCore.QSize(62, 20))
        self.label_admix_d.setObjectName("label_admix_d")
        self.lineEdit_admix_d = QtWidgets.QLineEdit(self.splitter_13)
        self.lineEdit_admix_d.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_admix_d.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_admix_d.setObjectName("lineEdit_admix_d")
        self.pushButton_admix_d = QtWidgets.QPushButton(self.splitter_13)
        self.pushButton_admix_d.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_admix_d.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_admix_d.setAutoDefault(False)
        self.pushButton_admix_d.setObjectName("pushButton_admix_d")
        self.splitter_6 = QtWidgets.QSplitter(self.splitter_70)
        self.splitter_6.setMinimumSize(QtCore.QSize(646, 20))
        self.splitter_6.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_6.setObjectName("splitter_6")
        self.label_admix_o = QtWidgets.QLabel(self.splitter_6)
        self.label_admix_o.setMinimumSize(QtCore.QSize(62, 20))
        self.label_admix_o.setMaximumSize(QtCore.QSize(62, 20))
        self.label_admix_o.setObjectName("label_admix_o")
        self.lineEdit_admix_o = QtWidgets.QLineEdit(self.splitter_6)
        self.lineEdit_admix_o.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_admix_o.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_admix_o.setObjectName("lineEdit_admix_o")
        self.pushButton_admix_o = QtWidgets.QPushButton(self.splitter_6)
        self.pushButton_admix_o.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_admix_o.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_admix_o.setAutoDefault(False)
        self.pushButton_admix_o.setObjectName("pushButton_admix_o")
        self.splitter_81 = QtWidgets.QSplitter(self.admix_tab)
        self.splitter_81.setGeometry(QtCore.QRect(20, 110, 161, 170))
        self.splitter_81.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_81.setMaximumSize(QtCore.QSize(161, 170))
        self.splitter_81.setOrientation(QtCore.Qt.Vertical)
        self.splitter_81.setObjectName("splitter_81")
        self.splitter_77 = QtWidgets.QSplitter(self.splitter_81)
        self.splitter_77.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_77.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_77.setObjectName("splitter_77")
        self.label_admix_sl = QtWidgets.QLabel(self.splitter_77)
        self.label_admix_sl.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_sl.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_sl.setObjectName("label_admix_sl")
        self.comboBox_admix_sl = QtWidgets.QComboBox(self.splitter_77)
        self.comboBox_admix_sl.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_admix_sl.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_admix_sl.setObjectName("comboBox_admix_sl")
        self.comboBox_admix_sl.addItem("")
        self.comboBox_admix_sl.addItem("")
        self.splitter_72 = QtWidgets.QSplitter(self.splitter_81)
        self.splitter_72.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_72.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_72.setObjectName("splitter_72")
        self.label_admix_x = QtWidgets.QLabel(self.splitter_72)
        self.label_admix_x.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_x.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_x.setObjectName("label_admix_x")
        self.doubleSpinBox_admix_x = QtWidgets.QDoubleSpinBox(self.splitter_72)
        self.doubleSpinBox_admix_x.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_x.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_x.setDecimals(6)
        self.doubleSpinBox_admix_x.setMinimum(0.0001)
        self.doubleSpinBox_admix_x.setProperty("value", 8.4)
        self.doubleSpinBox_admix_x.setObjectName("doubleSpinBox_admix_x")
        self.splitter_73 = QtWidgets.QSplitter(self.splitter_81)
        self.splitter_73.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_73.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_73.setObjectName("splitter_73")
        self.label_admix_y = QtWidgets.QLabel(self.splitter_73)
        self.label_admix_y.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_y.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_y.setObjectName("label_admix_y")
        self.doubleSpinBox_admix_y = QtWidgets.QDoubleSpinBox(self.splitter_73)
        self.doubleSpinBox_admix_y.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_y.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_y.setDecimals(6)
        self.doubleSpinBox_admix_y.setMinimum(0.0001)
        self.doubleSpinBox_admix_y.setProperty("value", 4.0)
        self.doubleSpinBox_admix_y.setObjectName("doubleSpinBox_admix_y")
        self.splitter_8 = QtWidgets.QSplitter(self.splitter_81)
        self.splitter_8.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_8.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_8.setObjectName("splitter_8")
        self.label_admix_c = QtWidgets.QLabel(self.splitter_8)
        self.label_admix_c.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_c.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_c.setObjectName("label_admix_c")
        self.comboBox_admix_c = QtWidgets.QComboBox(self.splitter_8)
        self.comboBox_admix_c.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_admix_c.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_admix_c.setEditable(True)
        self.comboBox_admix_c.setMaxVisibleItems(20)
        self.comboBox_admix_c.setObjectName("comboBox_admix_c")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.comboBox_admix_c.addItem("")
        self.splitter_76 = QtWidgets.QSplitter(self.splitter_81)
        self.splitter_76.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_76.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_76.setObjectName("splitter_76")
        self.label_admix_f = QtWidgets.QLabel(self.splitter_76)
        self.label_admix_f.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_f.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_f.setObjectName("label_admix_f")
        self.lineEdit_admix_f = QtWidgets.QLineEdit(self.splitter_76)
        self.lineEdit_admix_f.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_admix_f.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_admix_f.setObjectName("lineEdit_admix_f")
        self.splitter_71 = QtWidgets.QSplitter(self.splitter_81)
        self.splitter_71.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_71.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_71.setObjectName("splitter_71")
        self.label_admix_ft = QtWidgets.QLabel(self.splitter_71)
        self.label_admix_ft.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_ft.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_ft.setObjectName("label_admix_ft")
        self.comboBox_admix_ft = QtWidgets.QComboBox(self.splitter_71)
        self.comboBox_admix_ft.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_admix_ft.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_admix_ft.setObjectName("comboBox_admix_ft")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.comboBox_admix_ft.addItem("")
        self.splitter_78 = QtWidgets.QSplitter(self.splitter_81)
        self.splitter_78.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_78.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_78.setObjectName("splitter_78")
        self.label_admix_lws = QtWidgets.QLabel(self.splitter_78)
        self.label_admix_lws.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_lws.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_lws.setObjectName("label_admix_lws")
        self.doubleSpinBox_admix_lws = QtWidgets.QDoubleSpinBox(self.splitter_78)
        self.doubleSpinBox_admix_lws.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_lws.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_lws.setDecimals(7)
        self.doubleSpinBox_admix_lws.setMinimum(1e-06)
        self.doubleSpinBox_admix_lws.setSingleStep(1.0)
        self.doubleSpinBox_admix_lws.setProperty("value", 0.75)
        self.doubleSpinBox_admix_lws.setObjectName("doubleSpinBox_admix_lws")
        self.splitter_127 = QtWidgets.QSplitter(self.admix_tab)
        self.splitter_127.setGeometry(QtCore.QRect(190, 110, 161, 95))
        self.splitter_127.setMinimumSize(QtCore.QSize(161, 95))
        self.splitter_127.setOrientation(QtCore.Qt.Vertical)
        self.splitter_127.setObjectName("splitter_127")
        self.splitter_79 = QtWidgets.QSplitter(self.splitter_127)
        self.splitter_79.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_79.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_79.setObjectName("splitter_79")
        self.label_admix_dpi = QtWidgets.QLabel(self.splitter_79)
        self.label_admix_dpi.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_dpi.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_dpi.setObjectName("label_admix_dpi")
        self.spinBox_admix_dpi = QtWidgets.QSpinBox(self.splitter_79)
        self.spinBox_admix_dpi.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_admix_dpi.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_admix_dpi.setMinimum(300)
        self.spinBox_admix_dpi.setMaximum(5000)
        self.spinBox_admix_dpi.setProperty("value", 300)
        self.spinBox_admix_dpi.setObjectName("spinBox_admix_dpi")
        self.splitter_75 = QtWidgets.QSplitter(self.splitter_127)
        self.splitter_75.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_75.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_75.setObjectName("splitter_75")
        self.label_admix_fs = QtWidgets.QLabel(self.splitter_75)
        self.label_admix_fs.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_fs.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_fs.setObjectName("label_admix_fs")
        self.doubleSpinBox_admix_fs = QtWidgets.QDoubleSpinBox(self.splitter_75)
        self.doubleSpinBox_admix_fs.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_fs.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_fs.setDecimals(6)
        self.doubleSpinBox_admix_fs.setMinimum(0.0001)
        self.doubleSpinBox_admix_fs.setProperty("value", 14.0)
        self.doubleSpinBox_admix_fs.setObjectName("doubleSpinBox_admix_fs")
        self.splitter_74 = QtWidgets.QSplitter(self.splitter_127)
        self.splitter_74.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_74.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_74.setObjectName("splitter_74")
        self.label_admix_xt = QtWidgets.QLabel(self.splitter_74)
        self.label_admix_xt.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_xt.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_xt.setObjectName("label_admix_xt")
        self.doubleSpinBox_admix_xt = QtWidgets.QDoubleSpinBox(self.splitter_74)
        self.doubleSpinBox_admix_xt.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_xt.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_admix_xt.setDecimals(6)
        self.doubleSpinBox_admix_xt.setMinimum(0.0001)
        self.doubleSpinBox_admix_xt.setProperty("value", 9.0)
        self.doubleSpinBox_admix_xt.setObjectName("doubleSpinBox_admix_xt")
        self.splitter_80 = QtWidgets.QSplitter(self.splitter_127)
        self.splitter_80.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_80.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_80.setObjectName("splitter_80")
        self.label_admix_mode = QtWidgets.QLabel(self.splitter_80)
        self.label_admix_mode.setMinimumSize(QtCore.QSize(55, 20))
        self.label_admix_mode.setMaximumSize(QtCore.QSize(55, 20))
        self.label_admix_mode.setObjectName("label_admix_mode")
        self.comboBox_admix_mode = QtWidgets.QComboBox(self.splitter_80)
        self.comboBox_admix_mode.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_admix_mode.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_admix_mode.setObjectName("comboBox_admix_mode")
        self.comboBox_admix_mode.addItem("")
        self.comboBox_admix_mode.addItem("")
        self.tabWidget.addTab(self.admix_tab, "")
        self.rohpainter_tab = QtWidgets.QWidget()
        self.rohpainter_tab.setObjectName("rohpainter_tab")
        self.pushButton_rohpainter_RUN = QtWidgets.QPushButton(self.rohpainter_tab)
        self.pushButton_rohpainter_RUN.setGeometry(QtCore.QRect(20, 350, 661, 30))
        self.pushButton_rohpainter_RUN.setMinimumSize(QtCore.QSize(661, 30))
        self.pushButton_rohpainter_RUN.setMaximumSize(QtCore.QSize(661, 30))
        self.pushButton_rohpainter_RUN.setObjectName("pushButton_rohpainter_RUN")
        self.splitter_83 = QtWidgets.QSplitter(self.rohpainter_tab)
        self.splitter_83.setGeometry(QtCore.QRect(20, 11, 646, 80))
        self.splitter_83.setMinimumSize(QtCore.QSize(646, 80))
        self.splitter_83.setMaximumSize(QtCore.QSize(646, 70))
        self.splitter_83.setOrientation(QtCore.Qt.Vertical)
        self.splitter_83.setObjectName("splitter_83")
        self.splitter_7 = QtWidgets.QSplitter(self.splitter_83)
        self.splitter_7.setMinimumSize(QtCore.QSize(646, 20))
        self.splitter_7.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_7.setObjectName("splitter_7")
        self.label_rohpainter_d = QtWidgets.QLabel(self.splitter_7)
        self.label_rohpainter_d.setMinimumSize(QtCore.QSize(62, 20))
        self.label_rohpainter_d.setMaximumSize(QtCore.QSize(62, 20))
        self.label_rohpainter_d.setObjectName("label_rohpainter_d")
        self.lineEdit_rohpainter_d = QtWidgets.QLineEdit(self.splitter_7)
        self.lineEdit_rohpainter_d.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_rohpainter_d.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_rohpainter_d.setObjectName("lineEdit_rohpainter_d")
        self.pushButton_rohpainter_d = QtWidgets.QPushButton(self.splitter_7)
        self.pushButton_rohpainter_d.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_rohpainter_d.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_rohpainter_d.setAutoDefault(False)
        self.pushButton_rohpainter_d.setObjectName("pushButton_rohpainter_d")
        self.splitter_12 = QtWidgets.QSplitter(self.splitter_83)
        self.splitter_12.setMinimumSize(QtCore.QSize(646, 20))
        self.splitter_12.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_12.setObjectName("splitter_12")
        self.label_rohpainter_i = QtWidgets.QLabel(self.splitter_12)
        self.label_rohpainter_i.setMinimumSize(QtCore.QSize(62, 20))
        self.label_rohpainter_i.setMaximumSize(QtCore.QSize(62, 20))
        self.label_rohpainter_i.setObjectName("label_rohpainter_i")
        self.lineEdit_rohpainter_i = QtWidgets.QLineEdit(self.splitter_12)
        self.lineEdit_rohpainter_i.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_rohpainter_i.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_rohpainter_i.setObjectName("lineEdit_rohpainter_i")
        self.pushButton_rohpainter_i = QtWidgets.QPushButton(self.splitter_12)
        self.pushButton_rohpainter_i.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_rohpainter_i.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_rohpainter_i.setAutoDefault(False)
        self.pushButton_rohpainter_i.setFlat(False)
        self.pushButton_rohpainter_i.setObjectName("pushButton_rohpainter_i")
        self.splitter_82 = QtWidgets.QSplitter(self.splitter_83)
        self.splitter_82.setMinimumSize(QtCore.QSize(646, 20))
        self.splitter_82.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_82.setObjectName("splitter_82")
        self.label_rohpainter_o = QtWidgets.QLabel(self.splitter_82)
        self.label_rohpainter_o.setMinimumSize(QtCore.QSize(62, 20))
        self.label_rohpainter_o.setMaximumSize(QtCore.QSize(62, 20))
        self.label_rohpainter_o.setObjectName("label_rohpainter_o")
        self.lineEdit_rohpainter_o = QtWidgets.QLineEdit(self.splitter_82)
        self.lineEdit_rohpainter_o.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_rohpainter_o.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_rohpainter_o.setObjectName("lineEdit_rohpainter_o")
        self.pushButton_rohpainter_o = QtWidgets.QPushButton(self.splitter_82)
        self.pushButton_rohpainter_o.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_rohpainter_o.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_rohpainter_o.setAutoDefault(False)
        self.pushButton_rohpainter_o.setObjectName("pushButton_rohpainter_o")
        self.splitter_96 = QtWidgets.QSplitter(self.rohpainter_tab)
        self.splitter_96.setGeometry(QtCore.QRect(20, 110, 161, 170))
        self.splitter_96.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_96.setMaximumSize(QtCore.QSize(161, 170))
        self.splitter_96.setOrientation(QtCore.Qt.Vertical)
        self.splitter_96.setObjectName("splitter_96")
        self.splitter_91 = QtWidgets.QSplitter(self.splitter_96)
        self.splitter_91.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_91.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_91.setObjectName("splitter_91")
        self.label_rohpainter_Chr = QtWidgets.QLabel(self.splitter_91)
        self.label_rohpainter_Chr.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_Chr.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_Chr.setObjectName("label_rohpainter_Chr")
        self.lineEdit_rohpainter_Chr = QtWidgets.QLineEdit(self.splitter_91)
        self.lineEdit_rohpainter_Chr.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_rohpainter_Chr.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_rohpainter_Chr.setObjectName("lineEdit_rohpainter_Chr")
        self.splitter_87 = QtWidgets.QSplitter(self.splitter_96)
        self.splitter_87.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_87.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_87.setObjectName("splitter_87")
        self.label_rohpainter_t = QtWidgets.QLabel(self.splitter_87)
        self.label_rohpainter_t.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_t.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_t.setObjectName("label_rohpainter_t")
        self.lineEdit_rohpainter_t = QtWidgets.QLineEdit(self.splitter_87)
        self.lineEdit_rohpainter_t.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_rohpainter_t.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_rohpainter_t.setObjectName("lineEdit_rohpainter_t")
        self.splitter_85 = QtWidgets.QSplitter(self.splitter_96)
        self.splitter_85.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_85.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_85.setObjectName("splitter_85")
        self.label_rohpainter_tc = QtWidgets.QLabel(self.splitter_85)
        self.label_rohpainter_tc.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_tc.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_tc.setObjectName("label_rohpainter_tc")
        self.lineEdit_rohpainter_tc = QtWidgets.QLineEdit(self.splitter_85)
        self.lineEdit_rohpainter_tc.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_rohpainter_tc.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_rohpainter_tc.setObjectName("lineEdit_rohpainter_tc")
        self.splitter_84 = QtWidgets.QSplitter(self.splitter_96)
        self.splitter_84.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_84.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_84.setObjectName("splitter_84")
        self.label_rohpainter_tw = QtWidgets.QLabel(self.splitter_84)
        self.label_rohpainter_tw.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_tw.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_tw.setObjectName("label_rohpainter_tw")
        self.doubleSpinBox_rohpainter_tw = QtWidgets.QDoubleSpinBox(self.splitter_84)
        self.doubleSpinBox_rohpainter_tw.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_tw.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_tw.setMaximum(100.0)
        self.doubleSpinBox_rohpainter_tw.setSingleStep(0.1)
        self.doubleSpinBox_rohpainter_tw.setProperty("value", 0.75)
        self.doubleSpinBox_rohpainter_tw.setObjectName("doubleSpinBox_rohpainter_tw")
        self.splitter_86 = QtWidgets.QSplitter(self.splitter_96)
        self.splitter_86.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_86.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_86.setObjectName("splitter_86")
        self.label_rohpainter_sl = QtWidgets.QLabel(self.splitter_86)
        self.label_rohpainter_sl.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_sl.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_sl.setObjectName("label_rohpainter_sl")
        self.comboBox_rohpainter_sl = QtWidgets.QComboBox(self.splitter_86)
        self.comboBox_rohpainter_sl.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_rohpainter_sl.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_rohpainter_sl.setObjectName("comboBox_rohpainter_sl")
        self.comboBox_rohpainter_sl.addItem("")
        self.comboBox_rohpainter_sl.addItem("")
        self.splitter_94 = QtWidgets.QSplitter(self.splitter_96)
        self.splitter_94.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_94.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_94.setObjectName("splitter_94")
        self.label_rohpainter_xt = QtWidgets.QLabel(self.splitter_94)
        self.label_rohpainter_xt.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_xt.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_xt.setObjectName("label_rohpainter_xt")
        self.doubleSpinBox_rohpainter_xt = QtWidgets.QDoubleSpinBox(self.splitter_94)
        self.doubleSpinBox_rohpainter_xt.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_xt.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_xt.setDecimals(6)
        self.doubleSpinBox_rohpainter_xt.setMinimum(0.0001)
        self.doubleSpinBox_rohpainter_xt.setProperty("value", 9.0)
        self.doubleSpinBox_rohpainter_xt.setObjectName("doubleSpinBox_rohpainter_xt")
        self.splitter_95 = QtWidgets.QSplitter(self.splitter_96)
        self.splitter_95.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_95.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_95.setObjectName("splitter_95")
        self.label_rohpainter_yt = QtWidgets.QLabel(self.splitter_95)
        self.label_rohpainter_yt.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_yt.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_yt.setObjectName("label_rohpainter_yt")
        self.doubleSpinBox_rohpainter_yt = QtWidgets.QDoubleSpinBox(self.splitter_95)
        self.doubleSpinBox_rohpainter_yt.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_yt.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_yt.setDecimals(6)
        self.doubleSpinBox_rohpainter_yt.setMinimum(0.0001)
        self.doubleSpinBox_rohpainter_yt.setProperty("value", 9.0)
        self.doubleSpinBox_rohpainter_yt.setObjectName("doubleSpinBox_rohpainter_yt")
        self.splitter_99 = QtWidgets.QSplitter(self.rohpainter_tab)
        self.splitter_99.setGeometry(QtCore.QRect(190, 110, 161, 170))
        self.splitter_99.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_99.setOrientation(QtCore.Qt.Vertical)
        self.splitter_99.setObjectName("splitter_99")
        self.splitter_97 = QtWidgets.QSplitter(self.splitter_99)
        self.splitter_97.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_97.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_97.setObjectName("splitter_97")
        self.label_rohpainter_x = QtWidgets.QLabel(self.splitter_97)
        self.label_rohpainter_x.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_x.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_x.setObjectName("label_rohpainter_x")
        self.doubleSpinBox_rohpainter_x = QtWidgets.QDoubleSpinBox(self.splitter_97)
        self.doubleSpinBox_rohpainter_x.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_x.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_x.setDecimals(6)
        self.doubleSpinBox_rohpainter_x.setMinimum(0.0001)
        self.doubleSpinBox_rohpainter_x.setProperty("value", 10.0)
        self.doubleSpinBox_rohpainter_x.setObjectName("doubleSpinBox_rohpainter_x")
        self.splitter_98 = QtWidgets.QSplitter(self.splitter_99)
        self.splitter_98.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_98.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_98.setObjectName("splitter_98")
        self.label_rohpainter_y = QtWidgets.QLabel(self.splitter_98)
        self.label_rohpainter_y.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_y.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_y.setObjectName("label_rohpainter_y")
        self.doubleSpinBox_rohpainter_y = QtWidgets.QDoubleSpinBox(self.splitter_98)
        self.doubleSpinBox_rohpainter_y.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_y.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_y.setDecimals(6)
        self.doubleSpinBox_rohpainter_y.setMinimum(0.0001)
        self.doubleSpinBox_rohpainter_y.setProperty("value", 4.0)
        self.doubleSpinBox_rohpainter_y.setObjectName("doubleSpinBox_rohpainter_y")
        self.splitter_93 = QtWidgets.QSplitter(self.splitter_99)
        self.splitter_93.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_93.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_93.setObjectName("splitter_93")
        self.label_rohpainter_f = QtWidgets.QLabel(self.splitter_93)
        self.label_rohpainter_f.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_f.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_f.setObjectName("label_rohpainter_f")
        self.lineEdit_rohpainter_f = QtWidgets.QLineEdit(self.splitter_93)
        self.lineEdit_rohpainter_f.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_rohpainter_f.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_rohpainter_f.setObjectName("lineEdit_rohpainter_f")
        self.splitter_88 = QtWidgets.QSplitter(self.splitter_99)
        self.splitter_88.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_88.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_88.setObjectName("splitter_88")
        self.label_rohpainter_fs = QtWidgets.QLabel(self.splitter_88)
        self.label_rohpainter_fs.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_fs.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_fs.setObjectName("label_rohpainter_fs")
        self.doubleSpinBox_rohpainter_fs = QtWidgets.QDoubleSpinBox(self.splitter_88)
        self.doubleSpinBox_rohpainter_fs.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_fs.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_rohpainter_fs.setDecimals(6)
        self.doubleSpinBox_rohpainter_fs.setMinimum(0.0001)
        self.doubleSpinBox_rohpainter_fs.setProperty("value", 12.0)
        self.doubleSpinBox_rohpainter_fs.setObjectName("doubleSpinBox_rohpainter_fs")
        self.splitter_92 = QtWidgets.QSplitter(self.splitter_99)
        self.splitter_92.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_92.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_92.setObjectName("splitter_92")
        self.label_rohpainter_c = QtWidgets.QLabel(self.splitter_92)
        self.label_rohpainter_c.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_c.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_c.setObjectName("label_rohpainter_c")
        self.comboBox_rohpainter_c = QtWidgets.QComboBox(self.splitter_92)
        self.comboBox_rohpainter_c.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_rohpainter_c.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_rohpainter_c.setEditable(True)
        self.comboBox_rohpainter_c.setMaxVisibleItems(20)
        self.comboBox_rohpainter_c.setObjectName("comboBox_rohpainter_c")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.comboBox_rohpainter_c.addItem("")
        self.splitter_90 = QtWidgets.QSplitter(self.splitter_99)
        self.splitter_90.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_90.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_90.setObjectName("splitter_90")
        self.label_rohpainter_ft = QtWidgets.QLabel(self.splitter_90)
        self.label_rohpainter_ft.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_ft.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_ft.setObjectName("label_rohpainter_ft")
        self.comboBox_rohpainter_ft = QtWidgets.QComboBox(self.splitter_90)
        self.comboBox_rohpainter_ft.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_rohpainter_ft.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_rohpainter_ft.setObjectName("comboBox_rohpainter_ft")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.comboBox_rohpainter_ft.addItem("")
        self.splitter_89 = QtWidgets.QSplitter(self.splitter_99)
        self.splitter_89.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_89.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_89.setObjectName("splitter_89")
        self.label_rohpainter_dpi = QtWidgets.QLabel(self.splitter_89)
        self.label_rohpainter_dpi.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_dpi.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_dpi.setObjectName("label_rohpainter_dpi")
        self.spinBox_rohpainter_dpi = QtWidgets.QSpinBox(self.splitter_89)
        self.spinBox_rohpainter_dpi.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_rohpainter_dpi.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_rohpainter_dpi.setMinimum(300)
        self.spinBox_rohpainter_dpi.setMaximum(5000)
        self.spinBox_rohpainter_dpi.setProperty("value", 300)
        self.spinBox_rohpainter_dpi.setObjectName("spinBox_rohpainter_dpi")
        self.splitter_128 = QtWidgets.QSplitter(self.rohpainter_tab)
        self.splitter_128.setGeometry(QtCore.QRect(370, 110, 161, 20))
        self.splitter_128.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_128.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_128.setObjectName("splitter_128")
        self.label_rohpainter_mode = QtWidgets.QLabel(self.splitter_128)
        self.label_rohpainter_mode.setMinimumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_mode.setMaximumSize(QtCore.QSize(55, 20))
        self.label_rohpainter_mode.setObjectName("label_rohpainter_mode")
        self.comboBox_rohpainter_mode = QtWidgets.QComboBox(self.splitter_128)
        self.comboBox_rohpainter_mode.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_rohpainter_mode.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_rohpainter_mode.setObjectName("comboBox_rohpainter_mode")
        self.comboBox_rohpainter_mode.addItem("")
        self.comboBox_rohpainter_mode.addItem("")
        self.tabWidget.addTab(self.rohpainter_tab, "")
        self.manplot_tab = QtWidgets.QWidget()
        self.manplot_tab.setObjectName("manplot_tab")
        self.splitter_100 = QtWidgets.QSplitter(self.manplot_tab)
        self.splitter_100.setGeometry(QtCore.QRect(20, 11, 646, 55))
        self.splitter_100.setMinimumSize(QtCore.QSize(646, 55))
        self.splitter_100.setMaximumSize(QtCore.QSize(646, 45))
        self.splitter_100.setOrientation(QtCore.Qt.Vertical)
        self.splitter_100.setObjectName("splitter_100")
        self.splitter_10 = QtWidgets.QSplitter(self.splitter_100)
        self.splitter_10.setMinimumSize(QtCore.QSize(646, 20))
        self.splitter_10.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_10.setObjectName("splitter_10")
        self.label_manplot_d = QtWidgets.QLabel(self.splitter_10)
        self.label_manplot_d.setMinimumSize(QtCore.QSize(62, 20))
        self.label_manplot_d.setMaximumSize(QtCore.QSize(62, 20))
        self.label_manplot_d.setObjectName("label_manplot_d")
        self.lineEdit_manplot_d = QtWidgets.QLineEdit(self.splitter_10)
        self.lineEdit_manplot_d.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_manplot_d.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_manplot_d.setObjectName("lineEdit_manplot_d")
        self.pushButton_manplot_d = QtWidgets.QPushButton(self.splitter_10)
        self.pushButton_manplot_d.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_manplot_d.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_manplot_d.setAutoDefault(False)
        self.pushButton_manplot_d.setObjectName("pushButton_manplot_d")
        self.splitter_11 = QtWidgets.QSplitter(self.splitter_100)
        self.splitter_11.setMinimumSize(QtCore.QSize(646, 20))
        self.splitter_11.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_11.setObjectName("splitter_11")
        self.label_manplot_o = QtWidgets.QLabel(self.splitter_11)
        self.label_manplot_o.setMinimumSize(QtCore.QSize(62, 20))
        self.label_manplot_o.setMaximumSize(QtCore.QSize(62, 20))
        self.label_manplot_o.setObjectName("label_manplot_o")
        self.lineEdit_manplot_o = QtWidgets.QLineEdit(self.splitter_11)
        self.lineEdit_manplot_o.setMinimumSize(QtCore.QSize(450, 20))
        self.lineEdit_manplot_o.setMaximumSize(QtCore.QSize(450, 20))
        self.lineEdit_manplot_o.setObjectName("lineEdit_manplot_o")
        self.pushButton_manplot_o = QtWidgets.QPushButton(self.splitter_11)
        self.pushButton_manplot_o.setMinimumSize(QtCore.QSize(75, 20))
        self.pushButton_manplot_o.setMaximumSize(QtCore.QSize(75, 20))
        self.pushButton_manplot_o.setAutoDefault(False)
        self.pushButton_manplot_o.setObjectName("pushButton_manplot_o")
        self.groupBox_sug1 = QtWidgets.QGroupBox(self.manplot_tab)
        self.groupBox_sug1.setGeometry(QtCore.QRect(400, 90, 250, 250))
        self.groupBox_sug1.setMinimumSize(QtCore.QSize(250, 250))
        self.groupBox_sug1.setMaximumSize(QtCore.QSize(250, 250))
        self.groupBox_sug1.setCheckable(True)
        self.groupBox_sug1.setChecked(False)
        self.groupBox_sug1.setObjectName("groupBox_sug1")
        self.groupBox_sug2 = QtWidgets.QGroupBox(self.groupBox_sug1)
        self.groupBox_sug2.setGeometry(QtCore.QRect(10, 120, 231, 121))
        self.groupBox_sug2.setMinimumSize(QtCore.QSize(231, 121))
        self.groupBox_sug2.setCheckable(True)
        self.groupBox_sug2.setChecked(False)
        self.groupBox_sug2.setObjectName("groupBox_sug2")
        self.splitter_124 = QtWidgets.QSplitter(self.groupBox_sug2)
        self.splitter_124.setGeometry(QtCore.QRect(10, 30, 210, 70))
        self.splitter_124.setMinimumSize(QtCore.QSize(210, 70))
        self.splitter_124.setMaximumSize(QtCore.QSize(201, 70))
        self.splitter_124.setOrientation(QtCore.Qt.Vertical)
        self.splitter_124.setObjectName("splitter_124")
        self.splitter_121 = QtWidgets.QSplitter(self.splitter_124)
        self.splitter_121.setMinimumSize(QtCore.QSize(191, 20))
        self.splitter_121.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_121.setObjectName("splitter_121")
        self.label_manplot_sug2 = QtWidgets.QLabel(self.splitter_121)
        self.label_manplot_sug2.setMinimumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug2.setMaximumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug2.setObjectName("label_manplot_sug2")
        self.doubleSpinBox_manplot_sug2 = QtWidgets.QDoubleSpinBox(self.splitter_121)
        self.doubleSpinBox_manplot_sug2.setMinimumSize(QtCore.QSize(131, 20))
        self.doubleSpinBox_manplot_sug2.setMaximumSize(QtCore.QSize(131, 20))
        self.doubleSpinBox_manplot_sug2.setDecimals(12)
        self.doubleSpinBox_manplot_sug2.setMinimum(-1e+64)
        self.doubleSpinBox_manplot_sug2.setMaximum(1e+64)
        self.doubleSpinBox_manplot_sug2.setSingleStep(1.0)
        self.doubleSpinBox_manplot_sug2.setProperty("value", 0.0)
        self.doubleSpinBox_manplot_sug2.setObjectName("doubleSpinBox_manplot_sug2")
        self.splitter_122 = QtWidgets.QSplitter(self.splitter_124)
        self.splitter_122.setMinimumSize(QtCore.QSize(191, 20))
        self.splitter_122.setMaximumSize(QtCore.QSize(201, 20))
        self.splitter_122.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_122.setObjectName("splitter_122")
        self.label_manplot_sug2lw = QtWidgets.QLabel(self.splitter_122)
        self.label_manplot_sug2lw.setMinimumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug2lw.setMaximumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug2lw.setObjectName("label_manplot_sug2lw")
        self.doubleSpinBox_manplot_sug2lw = QtWidgets.QDoubleSpinBox(self.splitter_122)
        self.doubleSpinBox_manplot_sug2lw.setMinimumSize(QtCore.QSize(131, 20))
        self.doubleSpinBox_manplot_sug2lw.setMaximumSize(QtCore.QSize(131, 20))
        self.doubleSpinBox_manplot_sug2lw.setDecimals(4)
        self.doubleSpinBox_manplot_sug2lw.setMinimum(0.0001)
        self.doubleSpinBox_manplot_sug2lw.setMaximum(100.0)
        self.doubleSpinBox_manplot_sug2lw.setSingleStep(0.5)
        self.doubleSpinBox_manplot_sug2lw.setProperty("value", 0.5)
        self.doubleSpinBox_manplot_sug2lw.setObjectName("doubleSpinBox_manplot_sug2lw")
        self.splitter_123 = QtWidgets.QSplitter(self.splitter_124)
        self.splitter_123.setMinimumSize(QtCore.QSize(191, 20))
        self.splitter_123.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_123.setObjectName("splitter_123")
        self.label_manplot_sug2c = QtWidgets.QLabel(self.splitter_123)
        self.label_manplot_sug2c.setMinimumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug2c.setMaximumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug2c.setObjectName("label_manplot_sug2c")
        self.lineEdit_manplot_sug2c = QtWidgets.QLineEdit(self.splitter_123)
        self.lineEdit_manplot_sug2c.setMinimumSize(QtCore.QSize(131, 20))
        self.lineEdit_manplot_sug2c.setMaximumSize(QtCore.QSize(131, 20))
        self.lineEdit_manplot_sug2c.setObjectName("lineEdit_manplot_sug2c")
        self.splitter_120 = QtWidgets.QSplitter(self.groupBox_sug1)
        self.splitter_120.setGeometry(QtCore.QRect(20, 30, 220, 70))
        self.splitter_120.setMinimumSize(QtCore.QSize(220, 70))
        self.splitter_120.setMaximumSize(QtCore.QSize(201, 70))
        self.splitter_120.setOrientation(QtCore.Qt.Vertical)
        self.splitter_120.setObjectName("splitter_120")
        self.splitter_117 = QtWidgets.QSplitter(self.splitter_120)
        self.splitter_117.setMinimumSize(QtCore.QSize(191, 20))
        self.splitter_117.setMaximumSize(QtCore.QSize(201, 20))
        self.splitter_117.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_117.setObjectName("splitter_117")
        self.label_manplot_sug1 = QtWidgets.QLabel(self.splitter_117)
        self.label_manplot_sug1.setMinimumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug1.setMaximumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug1.setObjectName("label_manplot_sug1")
        self.doubleSpinBox_manplot_sug1 = QtWidgets.QDoubleSpinBox(self.splitter_117)
        self.doubleSpinBox_manplot_sug1.setMinimumSize(QtCore.QSize(131, 20))
        self.doubleSpinBox_manplot_sug1.setMaximumSize(QtCore.QSize(131, 20))
        self.doubleSpinBox_manplot_sug1.setDecimals(12)
        self.doubleSpinBox_manplot_sug1.setMinimum(-1e+64)
        self.doubleSpinBox_manplot_sug1.setMaximum(1e+64)
        self.doubleSpinBox_manplot_sug1.setSingleStep(1.0)
        self.doubleSpinBox_manplot_sug1.setObjectName("doubleSpinBox_manplot_sug1")
        self.splitter_118 = QtWidgets.QSplitter(self.splitter_120)
        self.splitter_118.setMinimumSize(QtCore.QSize(191, 20))
        self.splitter_118.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_118.setObjectName("splitter_118")
        self.label_manplot_sug1lw = QtWidgets.QLabel(self.splitter_118)
        self.label_manplot_sug1lw.setMinimumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug1lw.setMaximumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug1lw.setObjectName("label_manplot_sug1lw")
        self.doubleSpinBox_manplot_sug1lw = QtWidgets.QDoubleSpinBox(self.splitter_118)
        self.doubleSpinBox_manplot_sug1lw.setMinimumSize(QtCore.QSize(131, 20))
        self.doubleSpinBox_manplot_sug1lw.setMaximumSize(QtCore.QSize(131, 20))
        self.doubleSpinBox_manplot_sug1lw.setDecimals(4)
        self.doubleSpinBox_manplot_sug1lw.setMinimum(0.0001)
        self.doubleSpinBox_manplot_sug1lw.setMaximum(100.0)
        self.doubleSpinBox_manplot_sug1lw.setSingleStep(0.5)
        self.doubleSpinBox_manplot_sug1lw.setProperty("value", 0.5)
        self.doubleSpinBox_manplot_sug1lw.setObjectName("doubleSpinBox_manplot_sug1lw")
        self.splitter_119 = QtWidgets.QSplitter(self.splitter_120)
        self.splitter_119.setMinimumSize(QtCore.QSize(191, 20))
        self.splitter_119.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_119.setObjectName("splitter_119")
        self.label_manplot_sug1c = QtWidgets.QLabel(self.splitter_119)
        self.label_manplot_sug1c.setMinimumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug1c.setMaximumSize(QtCore.QSize(65, 20))
        self.label_manplot_sug1c.setObjectName("label_manplot_sug1c")
        self.lineEdit_manplot_sug1c = QtWidgets.QLineEdit(self.splitter_119)
        self.lineEdit_manplot_sug1c.setMinimumSize(QtCore.QSize(131, 20))
        self.lineEdit_manplot_sug1c.setMaximumSize(QtCore.QSize(131, 20))
        self.lineEdit_manplot_sug1c.setObjectName("lineEdit_manplot_sug1c")
        self.pushButton_manplot_RUN = QtWidgets.QPushButton(self.manplot_tab)
        self.pushButton_manplot_RUN.setGeometry(QtCore.QRect(20, 350, 661, 30))
        self.pushButton_manplot_RUN.setMinimumSize(QtCore.QSize(661, 30))
        self.pushButton_manplot_RUN.setMaximumSize(QtCore.QSize(661, 30))
        self.pushButton_manplot_RUN.setObjectName("pushButton_manplot_RUN")
        self.splitter_115 = QtWidgets.QSplitter(self.manplot_tab)
        self.splitter_115.setGeometry(QtCore.QRect(190, 110, 161, 170))
        self.splitter_115.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_115.setOrientation(QtCore.Qt.Vertical)
        self.splitter_115.setObjectName("splitter_115")
        self.splitter_110 = QtWidgets.QSplitter(self.splitter_115)
        self.splitter_110.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_110.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_110.setObjectName("splitter_110")
        self.label_manplot_x = QtWidgets.QLabel(self.splitter_110)
        self.label_manplot_x.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_x.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_x.setObjectName("label_manplot_x")
        self.doubleSpinBox_manplot_x = QtWidgets.QDoubleSpinBox(self.splitter_110)
        self.doubleSpinBox_manplot_x.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_x.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_x.setDecimals(6)
        self.doubleSpinBox_manplot_x.setMinimum(0.0001)
        self.doubleSpinBox_manplot_x.setProperty("value", 8.0)
        self.doubleSpinBox_manplot_x.setObjectName("doubleSpinBox_manplot_x")
        self.splitter_109 = QtWidgets.QSplitter(self.splitter_115)
        self.splitter_109.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_109.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_109.setObjectName("splitter_109")
        self.label_manplot_y = QtWidgets.QLabel(self.splitter_109)
        self.label_manplot_y.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_y.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_y.setObjectName("label_manplot_y")
        self.doubleSpinBox_manplot_y = QtWidgets.QDoubleSpinBox(self.splitter_109)
        self.doubleSpinBox_manplot_y.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_y.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_y.setDecimals(6)
        self.doubleSpinBox_manplot_y.setMinimum(0.0001)
        self.doubleSpinBox_manplot_y.setProperty("value", 4.0)
        self.doubleSpinBox_manplot_y.setObjectName("doubleSpinBox_manplot_y")
        self.splitter_104 = QtWidgets.QSplitter(self.splitter_115)
        self.splitter_104.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_104.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_104.setObjectName("splitter_104")
        self.label_manplot_f = QtWidgets.QLabel(self.splitter_104)
        self.label_manplot_f.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_f.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_f.setObjectName("label_manplot_f")
        self.lineEdit_manplot_f = QtWidgets.QLineEdit(self.splitter_104)
        self.lineEdit_manplot_f.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_manplot_f.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_manplot_f.setObjectName("lineEdit_manplot_f")
        self.splitter_114 = QtWidgets.QSplitter(self.splitter_115)
        self.splitter_114.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_114.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_114.setObjectName("splitter_114")
        self.label_manplot_fs = QtWidgets.QLabel(self.splitter_114)
        self.label_manplot_fs.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_fs.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_fs.setObjectName("label_manplot_fs")
        self.doubleSpinBox_manplot_fs = QtWidgets.QDoubleSpinBox(self.splitter_114)
        self.doubleSpinBox_manplot_fs.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_fs.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_fs.setDecimals(6)
        self.doubleSpinBox_manplot_fs.setMinimum(0.0001)
        self.doubleSpinBox_manplot_fs.setProperty("value", 8.0)
        self.doubleSpinBox_manplot_fs.setObjectName("doubleSpinBox_manplot_fs")
        self.splitter_111 = QtWidgets.QSplitter(self.splitter_115)
        self.splitter_111.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_111.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_111.setObjectName("splitter_111")
        self.label_manplot_ft = QtWidgets.QLabel(self.splitter_111)
        self.label_manplot_ft.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_ft.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_ft.setObjectName("label_manplot_ft")
        self.comboBox_manplot_ft = QtWidgets.QComboBox(self.splitter_111)
        self.comboBox_manplot_ft.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_manplot_ft.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_manplot_ft.setObjectName("comboBox_manplot_ft")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.comboBox_manplot_ft.addItem("")
        self.splitter_113 = QtWidgets.QSplitter(self.splitter_115)
        self.splitter_113.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_113.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_113.setObjectName("splitter_113")
        self.label_manplot_c = QtWidgets.QLabel(self.splitter_113)
        self.label_manplot_c.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_c.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_c.setObjectName("label_manplot_c")
        self.comboBox_manplot_c = QtWidgets.QComboBox(self.splitter_113)
        self.comboBox_manplot_c.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_manplot_c.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_manplot_c.setEditable(True)
        self.comboBox_manplot_c.setMaxVisibleItems(20)
        self.comboBox_manplot_c.setObjectName("comboBox_manplot_c")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.comboBox_manplot_c.addItem("")
        self.splitter_108 = QtWidgets.QSplitter(self.splitter_115)
        self.splitter_108.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_108.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_108.setObjectName("splitter_108")
        self.label_manplot_dpi = QtWidgets.QLabel(self.splitter_108)
        self.label_manplot_dpi.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_dpi.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_dpi.setObjectName("label_manplot_dpi")
        self.spinBox_manplot_dpi = QtWidgets.QSpinBox(self.splitter_108)
        self.spinBox_manplot_dpi.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_manplot_dpi.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_manplot_dpi.setMinimum(300)
        self.spinBox_manplot_dpi.setMaximum(5000)
        self.spinBox_manplot_dpi.setProperty("value", 600)
        self.spinBox_manplot_dpi.setObjectName("spinBox_manplot_dpi")
        self.splitter_130 = QtWidgets.QSplitter(self.manplot_tab)
        self.splitter_130.setGeometry(QtCore.QRect(20, 110, 161, 195))
        self.splitter_130.setOrientation(QtCore.Qt.Vertical)
        self.splitter_130.setObjectName("splitter_130")
        self.splitter_116 = QtWidgets.QSplitter(self.splitter_130)
        self.splitter_116.setMinimumSize(QtCore.QSize(161, 170))
        self.splitter_116.setOrientation(QtCore.Qt.Vertical)
        self.splitter_116.setObjectName("splitter_116")
        self.splitter_101 = QtWidgets.QSplitter(self.splitter_116)
        self.splitter_101.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_101.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_101.setObjectName("splitter_101")
        self.label_manplot_nc = QtWidgets.QLabel(self.splitter_101)
        self.label_manplot_nc.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_nc.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_nc.setObjectName("label_manplot_nc")
        self.spinBox_manplot_nc = QtWidgets.QSpinBox(self.splitter_101)
        self.spinBox_manplot_nc.setMinimumSize(QtCore.QSize(101, 20))
        self.spinBox_manplot_nc.setMaximumSize(QtCore.QSize(101, 20))
        self.spinBox_manplot_nc.setMinimum(2)
        self.spinBox_manplot_nc.setMaximum(5000)
        self.spinBox_manplot_nc.setProperty("value", 10)
        self.spinBox_manplot_nc.setObjectName("spinBox_manplot_nc")
        self.splitter_102 = QtWidgets.QSplitter(self.splitter_116)
        self.splitter_102.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_102.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_102.setObjectName("splitter_102")
        self.label_manplot_ylab = QtWidgets.QLabel(self.splitter_102)
        self.label_manplot_ylab.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_ylab.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_ylab.setObjectName("label_manplot_ylab")
        self.lineEdit_manplot_ylab = QtWidgets.QLineEdit(self.splitter_102)
        self.lineEdit_manplot_ylab.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_manplot_ylab.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_manplot_ylab.setObjectName("lineEdit_manplot_ylab")
        self.splitter_103 = QtWidgets.QSplitter(self.splitter_116)
        self.splitter_103.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_103.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_103.setObjectName("splitter_103")
        self.label_manplot_xlab = QtWidgets.QLabel(self.splitter_103)
        self.label_manplot_xlab.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_xlab.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_xlab.setObjectName("label_manplot_xlab")
        self.lineEdit_manplot_xlab = QtWidgets.QLineEdit(self.splitter_103)
        self.lineEdit_manplot_xlab.setMinimumSize(QtCore.QSize(101, 20))
        self.lineEdit_manplot_xlab.setMaximumSize(QtCore.QSize(101, 20))
        self.lineEdit_manplot_xlab.setObjectName("lineEdit_manplot_xlab")
        self.splitter_105 = QtWidgets.QSplitter(self.splitter_116)
        self.splitter_105.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_105.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_105.setObjectName("splitter_105")
        self.label_manplot_xt = QtWidgets.QLabel(self.splitter_105)
        self.label_manplot_xt.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_xt.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_xt.setObjectName("label_manplot_xt")
        self.doubleSpinBox_manplot_xt = QtWidgets.QDoubleSpinBox(self.splitter_105)
        self.doubleSpinBox_manplot_xt.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_xt.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_xt.setDecimals(6)
        self.doubleSpinBox_manplot_xt.setMinimum(0.0001)
        self.doubleSpinBox_manplot_xt.setProperty("value", 9.0)
        self.doubleSpinBox_manplot_xt.setObjectName("doubleSpinBox_manplot_xt")
        self.splitter_106 = QtWidgets.QSplitter(self.splitter_116)
        self.splitter_106.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_106.setMaximumSize(QtCore.QSize(161, 20))
        self.splitter_106.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_106.setObjectName("splitter_106")
        self.label_manplot_yt = QtWidgets.QLabel(self.splitter_106)
        self.label_manplot_yt.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_yt.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_yt.setObjectName("label_manplot_yt")
        self.doubleSpinBox_manplot_yt = QtWidgets.QDoubleSpinBox(self.splitter_106)
        self.doubleSpinBox_manplot_yt.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_yt.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_yt.setDecimals(6)
        self.doubleSpinBox_manplot_yt.setMinimum(0.0001)
        self.doubleSpinBox_manplot_yt.setProperty("value", 9.0)
        self.doubleSpinBox_manplot_yt.setObjectName("doubleSpinBox_manplot_yt")
        self.splitter_107 = QtWidgets.QSplitter(self.splitter_116)
        self.splitter_107.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_107.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_107.setObjectName("splitter_107")
        self.label_manplot_s = QtWidgets.QLabel(self.splitter_107)
        self.label_manplot_s.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_s.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_s.setObjectName("label_manplot_s")
        self.doubleSpinBox_manplot_s = QtWidgets.QDoubleSpinBox(self.splitter_107)
        self.doubleSpinBox_manplot_s.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_s.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_s.setDecimals(1)
        self.doubleSpinBox_manplot_s.setMinimum(0.1)
        self.doubleSpinBox_manplot_s.setMaximum(200.0)
        self.doubleSpinBox_manplot_s.setSingleStep(10.0)
        self.doubleSpinBox_manplot_s.setProperty("value", 0.5)
        self.doubleSpinBox_manplot_s.setObjectName("doubleSpinBox_manplot_s")
        self.splitter_112 = QtWidgets.QSplitter(self.splitter_116)
        self.splitter_112.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_112.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_112.setObjectName("splitter_112")
        self.label_manplot_a = QtWidgets.QLabel(self.splitter_112)
        self.label_manplot_a.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_a.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_a.setObjectName("label_manplot_a")
        self.doubleSpinBox_manplot_a = QtWidgets.QDoubleSpinBox(self.splitter_112)
        self.doubleSpinBox_manplot_a.setMinimumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_a.setMaximumSize(QtCore.QSize(101, 20))
        self.doubleSpinBox_manplot_a.setDecimals(6)
        self.doubleSpinBox_manplot_a.setMinimum(0.0001)
        self.doubleSpinBox_manplot_a.setMaximum(1.0)
        self.doubleSpinBox_manplot_a.setSingleStep(0.0001)
        self.doubleSpinBox_manplot_a.setProperty("value", 1.0)
        self.doubleSpinBox_manplot_a.setObjectName("doubleSpinBox_manplot_a")
        self.splitter_129 = QtWidgets.QSplitter(self.splitter_130)
        self.splitter_129.setMinimumSize(QtCore.QSize(161, 20))
        self.splitter_129.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_129.setObjectName("splitter_129")
        self.label_manplot_mode = QtWidgets.QLabel(self.splitter_129)
        self.label_manplot_mode.setMinimumSize(QtCore.QSize(55, 20))
        self.label_manplot_mode.setMaximumSize(QtCore.QSize(55, 20))
        self.label_manplot_mode.setObjectName("label_manplot_mode")
        self.comboBox_manplot_mode = QtWidgets.QComboBox(self.splitter_129)
        self.comboBox_manplot_mode.setMinimumSize(QtCore.QSize(101, 20))
        self.comboBox_manplot_mode.setMaximumSize(QtCore.QSize(101, 20))
        self.comboBox_manplot_mode.setObjectName("comboBox_manplot_mode")
        self.comboBox_manplot_mode.addItem("")
        self.comboBox_manplot_mode.addItem("")
        self.tabWidget.addTab(self.manplot_tab, "")
        self.splitter_5 = QtWidgets.QSplitter(self.centralwidget)
        self.splitter_5.setGeometry(QtCore.QRect(10, 40, 701, 211))
        self.splitter_5.setMinimumSize(QtCore.QSize(701, 211))
        self.splitter_5.setMaximumSize(QtCore.QSize(701, 226))
        self.splitter_5.setOrientation(QtCore.Qt.Vertical)
        self.splitter_5.setObjectName("splitter_5")
        self.image = QtWidgets.QLabel(self.splitter_5)
        self.image.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.image.sizePolicy().hasHeightForWidth())
        self.image.setSizePolicy(sizePolicy)
        self.image.setMinimumSize(QtCore.QSize(701, 150))
        self.image.setMaximumSize(QtCore.QSize(701, 150))
        self.image.setText("")
        self.image.setTextFormat(QtCore.Qt.PlainText)
        self.image.setPixmap(QtGui.QPixmap(LOGO_PATH))
        self.image.setScaledContents(False)
        self.image.setObjectName("image")
        self.textBrowser = QtWidgets.QTextBrowser(self.splitter_5)
        self.textBrowser.setMinimumSize(QtCore.QSize(701, 71))
        self.textBrowser.setMaximumSize(QtCore.QSize(701, 71))
        self.textBrowser.setObjectName("textBrowser")
        GENOVIS_GUI.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(GENOVIS_GUI)
        self.statusbar.setObjectName("statusbar")
        GENOVIS_GUI.setStatusBar(self.statusbar)

        self.retranslateUi(GENOVIS_GUI)
        self.tabWidget.setCurrentIndex(2)
        self.comboBox_relmap_av.setCurrentIndex(1)
        self.comboBox_relmap_mask.setCurrentIndex(1)
        self.comboBox_relmap_a.setCurrentIndex(1)
        self.comboBox_relmap_sl.setCurrentIndex(1)
        self.comboBox_admix_sl.setCurrentIndex(1)
        self.comboBox_rohpainter_sl.setCurrentIndex(0)
        #RunButton
        self.pushButton_mapden_run.clicked.connect(self.run_mapden)
        self.pushButton_relmap_run.clicked.connect(self.run_relmap)
        self.pushButton_3dpca_RUN.clicked.connect(self.run_3dpca)
        self.pushButton_admix_RUN.clicked.connect(self.run_admix)
        self.pushButton_rohpainter_RUN.clicked.connect(self.run_rohpainter)
        self.pushButton_manplot_RUN.clicked.connect(self.run_manplot)
        QtCore.QMetaObject.connectSlotsByName(GENOVIS_GUI)
        #Browse
        self.pushButton_i_mapden.clicked.connect(lambda: self._browse_file(self.lineEdit_i_mapden))
        self.pushButton_m_mapden.clicked.connect(lambda: self._browse_file(self.lineEdit_m_mapden))
        self.pushButton_mapden_o.clicked.connect(lambda: self._browse_file(self.lineEdit_manplot_o))
        self.pushButton__relmap_relfile.clicked.connect(lambda: self._browse_file(self.lineEdit__relmap_relfile))
        self.pushButton_relmap_matindex.clicked.connect(lambda: self._browse_file(self.lineEdit_relmap_matindex))
        self.pushButton_relmap_o.clicked.connect(lambda: self._browse_file(self.lineEdit_relmap_o))
        self.pushButton_3dpca_evec.clicked.connect(lambda: self._browse_file(self.lineEdit_3dpca_evec))
        self.pushButton_3dpca_eval.clicked.connect(lambda: self._browse_file(self.lineEdit_3dpca_eval))
        self.pushButton_3dpca_o.clicked.connect(lambda: self._browse_file(self.lineEdit_3dpca_o))
        self.pushButton_admix_d.clicked.connect(lambda: self._browse_file(self.lineEdit_admix_d))
        self.pushButton_admix_o.clicked.connect(lambda: self._browse_file(self.lineEdit_admix_o))
        self.pushButton_rohpainter_d.clicked.connect(lambda: self._browse_file(self.lineEdit_rohpainter_d))
        self.pushButton_rohpainter_i.clicked.connect(lambda: self._browse_file(self.lineEdit_rohpainter_i))
        self.pushButton_rohpainter_o.clicked.connect(lambda: self._browse_file(self.lineEdit_rohpainter_o))
        self.pushButton_manplot_d.clicked.connect(lambda: self._browse_file(self.lineEdit_manplot_d))
        self.pushButton_manplot_o.clicked.connect(lambda: self._browse_file(self.lineEdit_manplot_o))

    def retranslateUi(self, GENOVIS_GUI):
        _translate = QtCore.QCoreApplication.translate
        GENOVIS_GUI.setWindowTitle(_translate("GENOVIS_GUI", "GENOVIS"))
        self.pushButton_mapden_run.setText(_translate("GENOVIS_GUI", "Run mapden"))
        self.label_m_mapden.setText(_translate("GENOVIS_GUI", "--m"))
        self.pushButton_m_mapden.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_i_mapden.setText(_translate("GENOVIS_GUI", "--i"))
        self.pushButton_i_mapden.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_mapden_o.setText(_translate("GENOVIS_GUI", "--o"))
        self.lineEdit_mapden_o.setText(_translate("GENOVIS_GUI", "mapden_plot"))
        self.pushButton_mapden_o.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_mapden_y.setText(_translate("GENOVIS_GUI", "--y"))
        self.label_mapden_x.setText(_translate("GENOVIS_GUI", "--x"))
        self.label_mapden_fs.setText(_translate("GENOVIS_GUI", "--fs"))
        self.label_mapden_pad.setText(_translate("GENOVIS_GUI", "--pad"))
        self.label_mapden_dpi.setText(_translate("GENOVIS_GUI", "--dpi"))
        self.label_mapden_b.setText(_translate("GENOVIS_GUI", "--b"))
        self.label_3dpca_mapden_Chrfs.setText(_translate("GENOVIS_GUI", "--Chrfs"))
        self.label_mapden_c.setText(_translate("GENOVIS_GUI", "--c"))
        self.comboBox_mapden_c.setCurrentText(_translate("GENOVIS_GUI", "plasma"))
        self.comboBox_mapden_c.setItemText(0, _translate("GENOVIS_GUI", "plasma"))
        self.comboBox_mapden_c.setItemText(1, _translate("GENOVIS_GUI", "viridis"))
        self.comboBox_mapden_c.setItemText(2, _translate("GENOVIS_GUI", "inferno"))
        self.comboBox_mapden_c.setItemText(3, _translate("GENOVIS_GUI", "magma"))
        self.comboBox_mapden_c.setItemText(4, _translate("GENOVIS_GUI", "cividis"))
        self.comboBox_mapden_c.setItemText(5, _translate("GENOVIS_GUI", "Greys"))
        self.comboBox_mapden_c.setItemText(6, _translate("GENOVIS_GUI", "Purples"))
        self.comboBox_mapden_c.setItemText(7, _translate("GENOVIS_GUI", "Blues"))
        self.comboBox_mapden_c.setItemText(8, _translate("GENOVIS_GUI", "Greens"))
        self.comboBox_mapden_c.setItemText(9, _translate("GENOVIS_GUI", "Oranges"))
        self.comboBox_mapden_c.setItemText(10, _translate("GENOVIS_GUI", "Reds"))
        self.comboBox_mapden_c.setItemText(11, _translate("GENOVIS_GUI", "YlOrBr"))
        self.comboBox_mapden_c.setItemText(12, _translate("GENOVIS_GUI", "YlOrRd"))
        self.comboBox_mapden_c.setItemText(13, _translate("GENOVIS_GUI", "OrRd"))
        self.comboBox_mapden_c.setItemText(14, _translate("GENOVIS_GUI", "PuRd"))
        self.comboBox_mapden_c.setItemText(15, _translate("GENOVIS_GUI", "RdPu"))
        self.comboBox_mapden_c.setItemText(16, _translate("GENOVIS_GUI", "BuPu"))
        self.comboBox_mapden_c.setItemText(17, _translate("GENOVIS_GUI", "GnBu"))
        self.comboBox_mapden_c.setItemText(18, _translate("GENOVIS_GUI", "PuBu"))
        self.comboBox_mapden_c.setItemText(19, _translate("GENOVIS_GUI", "YlGnBu"))
        self.comboBox_mapden_c.setItemText(20, _translate("GENOVIS_GUI", "PuBuGn"))
        self.comboBox_mapden_c.setItemText(21, _translate("GENOVIS_GUI", "BuGn"))
        self.comboBox_mapden_c.setItemText(22, _translate("GENOVIS_GUI", "YlGn"))
        self.comboBox_mapden_c.setItemText(23, _translate("GENOVIS_GUI", "binary"))
        self.comboBox_mapden_c.setItemText(24, _translate("GENOVIS_GUI", "gist_yarg"))
        self.comboBox_mapden_c.setItemText(25, _translate("GENOVIS_GUI", "gist_gray"))
        self.comboBox_mapden_c.setItemText(26, _translate("GENOVIS_GUI", "gray"))
        self.comboBox_mapden_c.setItemText(27, _translate("GENOVIS_GUI", "bone"))
        self.comboBox_mapden_c.setItemText(28, _translate("GENOVIS_GUI", "pink"))
        self.comboBox_mapden_c.setItemText(29, _translate("GENOVIS_GUI", "spring"))
        self.comboBox_mapden_c.setItemText(30, _translate("GENOVIS_GUI", "summer"))
        self.comboBox_mapden_c.setItemText(31, _translate("GENOVIS_GUI", "autumn"))
        self.comboBox_mapden_c.setItemText(32, _translate("GENOVIS_GUI", "winter"))
        self.comboBox_mapden_c.setItemText(33, _translate("GENOVIS_GUI", "cool"))
        self.comboBox_mapden_c.setItemText(34, _translate("GENOVIS_GUI", "Wistia"))
        self.comboBox_mapden_c.setItemText(35, _translate("GENOVIS_GUI", "hot"))
        self.comboBox_mapden_c.setItemText(36, _translate("GENOVIS_GUI", "afmhot"))
        self.comboBox_mapden_c.setItemText(37, _translate("GENOVIS_GUI", "gist_heat"))
        self.comboBox_mapden_c.setItemText(38, _translate("GENOVIS_GUI", "copper"))
        self.comboBox_mapden_c.setItemText(39, _translate("GENOVIS_GUI", "PiYG"))
        self.comboBox_mapden_c.setItemText(40, _translate("GENOVIS_GUI", "PRGn"))
        self.comboBox_mapden_c.setItemText(41, _translate("GENOVIS_GUI", "BrBG"))
        self.comboBox_mapden_c.setItemText(42, _translate("GENOVIS_GUI", "PuOr"))
        self.comboBox_mapden_c.setItemText(43, _translate("GENOVIS_GUI", "RdGy"))
        self.comboBox_mapden_c.setItemText(44, _translate("GENOVIS_GUI", "RdBu"))
        self.comboBox_mapden_c.setItemText(45, _translate("GENOVIS_GUI", "RdYlBu"))
        self.comboBox_mapden_c.setItemText(46, _translate("GENOVIS_GUI", "RdYlGn"))
        self.comboBox_mapden_c.setItemText(47, _translate("GENOVIS_GUI", "Spectral"))
        self.comboBox_mapden_c.setItemText(48, _translate("GENOVIS_GUI", "coolwarm"))
        self.comboBox_mapden_c.setItemText(49, _translate("GENOVIS_GUI", "bwr"))
        self.comboBox_mapden_c.setItemText(50, _translate("GENOVIS_GUI", "seismic"))
        self.comboBox_mapden_c.setItemText(51, _translate("GENOVIS_GUI", "twilight"))
        self.comboBox_mapden_c.setItemText(52, _translate("GENOVIS_GUI", "twilight_shifted"))
        self.comboBox_mapden_c.setItemText(53, _translate("GENOVIS_GUI", "hsv"))
        self.comboBox_mapden_c.setItemText(54, _translate("GENOVIS_GUI", "Pastel1"))
        self.comboBox_mapden_c.setItemText(55, _translate("GENOVIS_GUI", "Pastel2"))
        self.comboBox_mapden_c.setItemText(56, _translate("GENOVIS_GUI", "Paired"))
        self.comboBox_mapden_c.setItemText(57, _translate("GENOVIS_GUI", "Accent"))
        self.comboBox_mapden_c.setItemText(58, _translate("GENOVIS_GUI", "Dark2"))
        self.comboBox_mapden_c.setItemText(59, _translate("GENOVIS_GUI", "Set1"))
        self.comboBox_mapden_c.setItemText(60, _translate("GENOVIS_GUI", "Set2"))
        self.comboBox_mapden_c.setItemText(61, _translate("GENOVIS_GUI", "Set3"))
        self.comboBox_mapden_c.setItemText(62, _translate("GENOVIS_GUI", "tab10"))
        self.comboBox_mapden_c.setItemText(63, _translate("GENOVIS_GUI", "tab20"))
        self.comboBox_mapden_c.setItemText(64, _translate("GENOVIS_GUI", "tab20b"))
        self.comboBox_mapden_c.setItemText(65, _translate("GENOVIS_GUI", "tab20c"))
        self.comboBox_mapden_c.setItemText(66, _translate("GENOVIS_GUI", "flag"))
        self.comboBox_mapden_c.setItemText(67, _translate("GENOVIS_GUI", "prism"))
        self.comboBox_mapden_c.setItemText(68, _translate("GENOVIS_GUI", "ocean"))
        self.comboBox_mapden_c.setItemText(69, _translate("GENOVIS_GUI", "gist_earth"))
        self.comboBox_mapden_c.setItemText(70, _translate("GENOVIS_GUI", "terrain"))
        self.comboBox_mapden_c.setItemText(71, _translate("GENOVIS_GUI", "gist_stern"))
        self.comboBox_mapden_c.setItemText(72, _translate("GENOVIS_GUI", "gnuplot"))
        self.comboBox_mapden_c.setItemText(73, _translate("GENOVIS_GUI", "gnuplot2"))
        self.comboBox_mapden_c.setItemText(74, _translate("GENOVIS_GUI", "CMRmap"))
        self.comboBox_mapden_c.setItemText(75, _translate("GENOVIS_GUI", "cubehelix"))
        self.comboBox_mapden_c.setItemText(76, _translate("GENOVIS_GUI", "brg"))
        self.comboBox_mapden_c.setItemText(77, _translate("GENOVIS_GUI", "gist_rainbow"))
        self.comboBox_mapden_c.setItemText(78, _translate("GENOVIS_GUI", "rainbow"))
        self.comboBox_mapden_c.setItemText(79, _translate("GENOVIS_GUI", "YlOrRd"))
        self.comboBox_mapden_c.setItemText(80, _translate("GENOVIS_GUI", "turbo"))
        self.comboBox_mapden_c.setItemText(81, _translate("GENOVIS_GUI", "nipy_spectral"))
        self.comboBox_mapden_c.setItemText(82, _translate("GENOVIS_GUI", "gist_ncar"))
        self.label_mapden_ft.setText(_translate("GENOVIS_GUI", "--ft"))
        self.comboBox_mapden_ft.setItemText(0, _translate("GENOVIS_GUI", "jpg"))
        self.comboBox_mapden_ft.setItemText(1, _translate("GENOVIS_GUI", "jpeg"))
        self.comboBox_mapden_ft.setItemText(2, _translate("GENOVIS_GUI", "png"))
        self.comboBox_mapden_ft.setItemText(3, _translate("GENOVIS_GUI", "tif"))
        self.comboBox_mapden_ft.setItemText(4, _translate("GENOVIS_GUI", "tiff"))
        self.comboBox_mapden_ft.setItemText(5, _translate("GENOVIS_GUI", "svg"))
        self.comboBox_mapden_ft.setItemText(6, _translate("GENOVIS_GUI", "svgz"))
        self.comboBox_mapden_ft.setItemText(7, _translate("GENOVIS_GUI", "pdf"))
        self.comboBox_mapden_ft.setItemText(8, _translate("GENOVIS_GUI", "eps"))
        self.comboBox_mapden_ft.setItemText(9, _translate("GENOVIS_GUI", "pgf"))
        self.comboBox_mapden_ft.setItemText(10, _translate("GENOVIS_GUI", "ps"))
        self.comboBox_mapden_ft.setItemText(11, _translate("GENOVIS_GUI", "raw"))
        self.comboBox_mapden_ft.setItemText(12, _translate("GENOVIS_GUI", "rgba"))
        self.comboBox_mapden_ft.setItemText(13, _translate("GENOVIS_GUI", "webp"))
        self.label_mapden_f.setText(_translate("GENOVIS_GUI", "--f"))
        self.lineEdit_mapden_f.setText(_translate("GENOVIS_GUI", "Calibri"))
        self.label_mapden_chr.setText(_translate("GENOVIS_GUI", "--Chr"))
        self.lineEdit_mapden_chr.setText(_translate("GENOVIS_GUI", "Chromosome"))
        self.label_mapden_mode.setText(_translate("GENOVIS_GUI", "--mode"))
        self.comboBox_mapden_mode.setItemText(0, _translate("GENOVIS_GUI", "int"))
        self.comboBox_mapden_mode.setItemText(1, _translate("GENOVIS_GUI", "solid"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.mapden_tab), _translate("GENOVIS_GUI", "mapden"))
        self.pushButton_relmap_run.setText(_translate("GENOVIS_GUI", "Run relmap"))
        self.label__relmap_relfile.setText(_translate("GENOVIS_GUI", "--relfile"))
        self.pushButton__relmap_relfile.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_relmap_matindex.setText(_translate("GENOVIS_GUI", "--matindex"))
        self.lineEdit_relmap_matindex.setText(_translate("GENOVIS_GUI", "None"))
        self.pushButton_relmap_matindex.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_relmap_o.setText(_translate("GENOVIS_GUI", "--o"))
        self.lineEdit_relmap_o.setText(_translate("GENOVIS_GUI", "relmap_plot"))
        self.pushButton_relmap_o.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_relmap_rf.setText(_translate("GENOVIS_GUI", "--rf"))
        self.comboBox_relmap_rf.setCurrentText(_translate("GENOVIS_GUI", "col"))
        self.comboBox_relmap_rf.setItemText(0, _translate("GENOVIS_GUI", "col"))
        self.comboBox_relmap_rf.setItemText(1, _translate("GENOVIS_GUI", "mat"))
        self.label_relmap_av.setText(_translate("GENOVIS_GUI", "--av"))
        self.comboBox_relmap_av.setCurrentText(_translate("GENOVIS_GUI", "false"))
        self.comboBox_relmap_av.setItemText(0, _translate("GENOVIS_GUI", "true"))
        self.comboBox_relmap_av.setItemText(1, _translate("GENOVIS_GUI", "false"))
        self.label_relmap_mask.setText(_translate("GENOVIS_GUI", "--mask"))
        self.comboBox_relmap_mask.setCurrentText(_translate("GENOVIS_GUI", "false"))
        self.comboBox_relmap_mask.setItemText(0, _translate("GENOVIS_GUI", "true"))
        self.comboBox_relmap_mask.setItemText(1, _translate("GENOVIS_GUI", "false"))
        self.label_relmap_a.setText(_translate("GENOVIS_GUI", "--a"))
        self.comboBox_relmap_a.setCurrentText(_translate("GENOVIS_GUI", "false"))
        self.comboBox_relmap_a.setItemText(0, _translate("GENOVIS_GUI", "true"))
        self.comboBox_relmap_a.setItemText(1, _translate("GENOVIS_GUI", "false"))
        self.label_relmap_sl.setText(_translate("GENOVIS_GUI", "--sl"))
        self.comboBox_relmap_sl.setCurrentText(_translate("GENOVIS_GUI", "false"))
        self.comboBox_relmap_sl.setItemText(0, _translate("GENOVIS_GUI", "true"))
        self.comboBox_relmap_sl.setItemText(1, _translate("GENOVIS_GUI", "false"))
        self.label_relmap_lc.setText(_translate("GENOVIS_GUI", "--lc"))
        self.lineEdit_relmap_lc.setText(_translate("GENOVIS_GUI", "black"))
        self.label_relmap_t.setText(_translate("GENOVIS_GUI", "--t"))
        self.lineEdit_relmap_t.setText(_translate("GENOVIS_GUI", "Relationship"))
        self.label_relmap_x.setText(_translate("GENOVIS_GUI", "--x"))
        self.label_relmap_y.setText(_translate("GENOVIS_GUI", "--y"))
        self.label_relmap_pfs.setText(_translate("GENOVIS_GUI", "--pfs"))
        self.label_relmap_xyfs.setText(_translate("GENOVIS_GUI", "--xyfs"))
        self.label_relmap_lws.setText(_translate("GENOVIS_GUI", "--lws"))
        self.label_relmap_afs.setText(_translate("GENOVIS_GUI", "--afs"))
        self.label_relmap_dpi.setText(_translate("GENOVIS_GUI", "--dpi"))
        self.label_relmap_ft.setText(_translate("GENOVIS_GUI", "--ft"))
        self.comboBox_relmap_ft.setItemText(0, _translate("GENOVIS_GUI", "jpg"))
        self.comboBox_relmap_ft.setItemText(1, _translate("GENOVIS_GUI", "jpeg"))
        self.comboBox_relmap_ft.setItemText(2, _translate("GENOVIS_GUI", "png"))
        self.comboBox_relmap_ft.setItemText(3, _translate("GENOVIS_GUI", "tif"))
        self.comboBox_relmap_ft.setItemText(4, _translate("GENOVIS_GUI", "tiff"))
        self.comboBox_relmap_ft.setItemText(5, _translate("GENOVIS_GUI", "svg"))
        self.comboBox_relmap_ft.setItemText(6, _translate("GENOVIS_GUI", "svgz"))
        self.comboBox_relmap_ft.setItemText(7, _translate("GENOVIS_GUI", "pdf"))
        self.comboBox_relmap_ft.setItemText(8, _translate("GENOVIS_GUI", "eps"))
        self.comboBox_relmap_ft.setItemText(9, _translate("GENOVIS_GUI", "pgf"))
        self.comboBox_relmap_ft.setItemText(10, _translate("GENOVIS_GUI", "ps"))
        self.comboBox_relmap_ft.setItemText(11, _translate("GENOVIS_GUI", "raw"))
        self.comboBox_relmap_ft.setItemText(12, _translate("GENOVIS_GUI", "rgba"))
        self.comboBox_relmap_ft.setItemText(13, _translate("GENOVIS_GUI", "webp"))
        self.label_relmap_c.setText(_translate("GENOVIS_GUI", "--c"))
        self.comboBox_relmap_c.setCurrentText(_translate("GENOVIS_GUI", "plasma"))
        self.comboBox_relmap_c.setItemText(0, _translate("GENOVIS_GUI", "plasma"))
        self.comboBox_relmap_c.setItemText(1, _translate("GENOVIS_GUI", "viridis"))
        self.comboBox_relmap_c.setItemText(2, _translate("GENOVIS_GUI", "inferno"))
        self.comboBox_relmap_c.setItemText(3, _translate("GENOVIS_GUI", "magma"))
        self.comboBox_relmap_c.setItemText(4, _translate("GENOVIS_GUI", "cividis"))
        self.comboBox_relmap_c.setItemText(5, _translate("GENOVIS_GUI", "Greys"))
        self.comboBox_relmap_c.setItemText(6, _translate("GENOVIS_GUI", "Purples"))
        self.comboBox_relmap_c.setItemText(7, _translate("GENOVIS_GUI", "Blues"))
        self.comboBox_relmap_c.setItemText(8, _translate("GENOVIS_GUI", "Greens"))
        self.comboBox_relmap_c.setItemText(9, _translate("GENOVIS_GUI", "Oranges"))
        self.comboBox_relmap_c.setItemText(10, _translate("GENOVIS_GUI", "Reds"))
        self.comboBox_relmap_c.setItemText(11, _translate("GENOVIS_GUI", "YlOrBr"))
        self.comboBox_relmap_c.setItemText(12, _translate("GENOVIS_GUI", "YlOrRd"))
        self.comboBox_relmap_c.setItemText(13, _translate("GENOVIS_GUI", "OrRd"))
        self.comboBox_relmap_c.setItemText(14, _translate("GENOVIS_GUI", "PuRd"))
        self.comboBox_relmap_c.setItemText(15, _translate("GENOVIS_GUI", "RdPu"))
        self.comboBox_relmap_c.setItemText(16, _translate("GENOVIS_GUI", "BuPu"))
        self.comboBox_relmap_c.setItemText(17, _translate("GENOVIS_GUI", "GnBu"))
        self.comboBox_relmap_c.setItemText(18, _translate("GENOVIS_GUI", "PuBu"))
        self.comboBox_relmap_c.setItemText(19, _translate("GENOVIS_GUI", "YlGnBu"))
        self.comboBox_relmap_c.setItemText(20, _translate("GENOVIS_GUI", "PuBuGn"))
        self.comboBox_relmap_c.setItemText(21, _translate("GENOVIS_GUI", "BuGn"))
        self.comboBox_relmap_c.setItemText(22, _translate("GENOVIS_GUI", "YlGn"))
        self.comboBox_relmap_c.setItemText(23, _translate("GENOVIS_GUI", "binary"))
        self.comboBox_relmap_c.setItemText(24, _translate("GENOVIS_GUI", "gist_yarg"))
        self.comboBox_relmap_c.setItemText(25, _translate("GENOVIS_GUI", "gist_gray"))
        self.comboBox_relmap_c.setItemText(26, _translate("GENOVIS_GUI", "gray"))
        self.comboBox_relmap_c.setItemText(27, _translate("GENOVIS_GUI", "bone"))
        self.comboBox_relmap_c.setItemText(28, _translate("GENOVIS_GUI", "pink"))
        self.comboBox_relmap_c.setItemText(29, _translate("GENOVIS_GUI", "spring"))
        self.comboBox_relmap_c.setItemText(30, _translate("GENOVIS_GUI", "summer"))
        self.comboBox_relmap_c.setItemText(31, _translate("GENOVIS_GUI", "autumn"))
        self.comboBox_relmap_c.setItemText(32, _translate("GENOVIS_GUI", "winter"))
        self.comboBox_relmap_c.setItemText(33, _translate("GENOVIS_GUI", "cool"))
        self.comboBox_relmap_c.setItemText(34, _translate("GENOVIS_GUI", "Wistia"))
        self.comboBox_relmap_c.setItemText(35, _translate("GENOVIS_GUI", "hot"))
        self.comboBox_relmap_c.setItemText(36, _translate("GENOVIS_GUI", "afmhot"))
        self.comboBox_relmap_c.setItemText(37, _translate("GENOVIS_GUI", "gist_heat"))
        self.comboBox_relmap_c.setItemText(38, _translate("GENOVIS_GUI", "copper"))
        self.comboBox_relmap_c.setItemText(39, _translate("GENOVIS_GUI", "PiYG"))
        self.comboBox_relmap_c.setItemText(40, _translate("GENOVIS_GUI", "PRGn"))
        self.comboBox_relmap_c.setItemText(41, _translate("GENOVIS_GUI", "BrBG"))
        self.comboBox_relmap_c.setItemText(42, _translate("GENOVIS_GUI", "PuOr"))
        self.comboBox_relmap_c.setItemText(43, _translate("GENOVIS_GUI", "RdGy"))
        self.comboBox_relmap_c.setItemText(44, _translate("GENOVIS_GUI", "RdBu"))
        self.comboBox_relmap_c.setItemText(45, _translate("GENOVIS_GUI", "RdYlBu"))
        self.comboBox_relmap_c.setItemText(46, _translate("GENOVIS_GUI", "RdYlGn"))
        self.comboBox_relmap_c.setItemText(47, _translate("GENOVIS_GUI", "Spectral"))
        self.comboBox_relmap_c.setItemText(48, _translate("GENOVIS_GUI", "coolwarm"))
        self.comboBox_relmap_c.setItemText(49, _translate("GENOVIS_GUI", "bwr"))
        self.comboBox_relmap_c.setItemText(50, _translate("GENOVIS_GUI", "seismic"))
        self.comboBox_relmap_c.setItemText(51, _translate("GENOVIS_GUI", "twilight"))
        self.comboBox_relmap_c.setItemText(52, _translate("GENOVIS_GUI", "twilight_shifted"))
        self.comboBox_relmap_c.setItemText(53, _translate("GENOVIS_GUI", "hsv"))
        self.comboBox_relmap_c.setItemText(54, _translate("GENOVIS_GUI", "Pastel1"))
        self.comboBox_relmap_c.setItemText(55, _translate("GENOVIS_GUI", "Pastel2"))
        self.comboBox_relmap_c.setItemText(56, _translate("GENOVIS_GUI", "Paired"))
        self.comboBox_relmap_c.setItemText(57, _translate("GENOVIS_GUI", "Accent"))
        self.comboBox_relmap_c.setItemText(58, _translate("GENOVIS_GUI", "Dark2"))
        self.comboBox_relmap_c.setItemText(59, _translate("GENOVIS_GUI", "Set1"))
        self.comboBox_relmap_c.setItemText(60, _translate("GENOVIS_GUI", "Set2"))
        self.comboBox_relmap_c.setItemText(61, _translate("GENOVIS_GUI", "Set3"))
        self.comboBox_relmap_c.setItemText(62, _translate("GENOVIS_GUI", "tab10"))
        self.comboBox_relmap_c.setItemText(63, _translate("GENOVIS_GUI", "tab20"))
        self.comboBox_relmap_c.setItemText(64, _translate("GENOVIS_GUI", "tab20b"))
        self.comboBox_relmap_c.setItemText(65, _translate("GENOVIS_GUI", "tab20c"))
        self.comboBox_relmap_c.setItemText(66, _translate("GENOVIS_GUI", "flag"))
        self.comboBox_relmap_c.setItemText(67, _translate("GENOVIS_GUI", "prism"))
        self.comboBox_relmap_c.setItemText(68, _translate("GENOVIS_GUI", "ocean"))
        self.comboBox_relmap_c.setItemText(69, _translate("GENOVIS_GUI", "gist_earth"))
        self.comboBox_relmap_c.setItemText(70, _translate("GENOVIS_GUI", "terrain"))
        self.comboBox_relmap_c.setItemText(71, _translate("GENOVIS_GUI", "gist_stern"))
        self.comboBox_relmap_c.setItemText(72, _translate("GENOVIS_GUI", "gnuplot"))
        self.comboBox_relmap_c.setItemText(73, _translate("GENOVIS_GUI", "gnuplot2"))
        self.comboBox_relmap_c.setItemText(74, _translate("GENOVIS_GUI", "CMRmap"))
        self.comboBox_relmap_c.setItemText(75, _translate("GENOVIS_GUI", "cubehelix"))
        self.comboBox_relmap_c.setItemText(76, _translate("GENOVIS_GUI", "brg"))
        self.comboBox_relmap_c.setItemText(77, _translate("GENOVIS_GUI", "gist_rainbow"))
        self.comboBox_relmap_c.setItemText(78, _translate("GENOVIS_GUI", "rainbow"))
        self.comboBox_relmap_c.setItemText(79, _translate("GENOVIS_GUI", "jet"))
        self.comboBox_relmap_c.setItemText(80, _translate("GENOVIS_GUI", "turbo"))
        self.comboBox_relmap_c.setItemText(81, _translate("GENOVIS_GUI", "nipy_spectral"))
        self.comboBox_relmap_c.setItemText(82, _translate("GENOVIS_GUI", "gist_ncar"))
        self.label_relmap_f.setText(_translate("GENOVIS_GUI", "--f"))
        self.lineEdit_relmap_f.setText(_translate("GENOVIS_GUI", "Calibri"))
        self.label_relmap_mode.setText(_translate("GENOVIS_GUI", "--mode"))
        self.comboBox_relmap_mode.setItemText(0, _translate("GENOVIS_GUI", "int"))
        self.comboBox_relmap_mode.setItemText(1, _translate("GENOVIS_GUI", "solid"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.relmap_tab), _translate("GENOVIS_GUI", "relmap"))
        self.pushButton_3dpca_RUN.setText(_translate("GENOVIS_GUI", "Run 3dpca"))
        self.label_3dpca_evec.setText(_translate("GENOVIS_GUI", "--evec"))
        self.pushButton_3dpca_evec.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_3dpca_eval.setText(_translate("GENOVIS_GUI", "--eval"))
        self.pushButton_3dpca_eval.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_3dpca_o.setText(_translate("GENOVIS_GUI", "--o"))
        self.lineEdit_3dpca_o.setText(_translate("GENOVIS_GUI", "3pca_plot"))
        self.pushButton_3dpca_o.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_3dpca_fp.setText(_translate("GENOVIS_GUI", "--fp"))
        self.label_3dpca_sp.setText(_translate("GENOVIS_GUI", "--sp"))
        self.label_3dpca_tp.setText(_translate("GENOVIS_GUI", "--tp"))
        self.label_3dpca_s.setText(_translate("GENOVIS_GUI", "--s"))
        self.label_3dpca_c.setText(_translate("GENOVIS_GUI", "--c"))
        self.comboBox_3dpca_c.setCurrentText(_translate("GENOVIS_GUI", "plasma"))
        self.comboBox_3dpca_c.setItemText(0, _translate("GENOVIS_GUI", "plasma"))
        self.comboBox_3dpca_c.setItemText(1, _translate("GENOVIS_GUI", "viridis"))
        self.comboBox_3dpca_c.setItemText(2, _translate("GENOVIS_GUI", "inferno"))
        self.comboBox_3dpca_c.setItemText(3, _translate("GENOVIS_GUI", "magma"))
        self.comboBox_3dpca_c.setItemText(4, _translate("GENOVIS_GUI", "cividis"))
        self.comboBox_3dpca_c.setItemText(5, _translate("GENOVIS_GUI", "Greys"))
        self.comboBox_3dpca_c.setItemText(6, _translate("GENOVIS_GUI", "Purples"))
        self.comboBox_3dpca_c.setItemText(7, _translate("GENOVIS_GUI", "Blues"))
        self.comboBox_3dpca_c.setItemText(8, _translate("GENOVIS_GUI", "Greens"))
        self.comboBox_3dpca_c.setItemText(9, _translate("GENOVIS_GUI", "Oranges"))
        self.comboBox_3dpca_c.setItemText(10, _translate("GENOVIS_GUI", "Reds"))
        self.comboBox_3dpca_c.setItemText(11, _translate("GENOVIS_GUI", "YlOrBr"))
        self.comboBox_3dpca_c.setItemText(12, _translate("GENOVIS_GUI", "YlOrRd"))
        self.comboBox_3dpca_c.setItemText(13, _translate("GENOVIS_GUI", "OrRd"))
        self.comboBox_3dpca_c.setItemText(14, _translate("GENOVIS_GUI", "PuRd"))
        self.comboBox_3dpca_c.setItemText(15, _translate("GENOVIS_GUI", "RdPu"))
        self.comboBox_3dpca_c.setItemText(16, _translate("GENOVIS_GUI", "BuPu"))
        self.comboBox_3dpca_c.setItemText(17, _translate("GENOVIS_GUI", "GnBu"))
        self.comboBox_3dpca_c.setItemText(18, _translate("GENOVIS_GUI", "PuBu"))
        self.comboBox_3dpca_c.setItemText(19, _translate("GENOVIS_GUI", "YlGnBu"))
        self.comboBox_3dpca_c.setItemText(20, _translate("GENOVIS_GUI", "PuBuGn"))
        self.comboBox_3dpca_c.setItemText(21, _translate("GENOVIS_GUI", "BuGn"))
        self.comboBox_3dpca_c.setItemText(22, _translate("GENOVIS_GUI", "YlGn"))
        self.comboBox_3dpca_c.setItemText(23, _translate("GENOVIS_GUI", "binary"))
        self.comboBox_3dpca_c.setItemText(24, _translate("GENOVIS_GUI", "gist_yarg"))
        self.comboBox_3dpca_c.setItemText(25, _translate("GENOVIS_GUI", "gist_gray"))
        self.comboBox_3dpca_c.setItemText(26, _translate("GENOVIS_GUI", "gray"))
        self.comboBox_3dpca_c.setItemText(27, _translate("GENOVIS_GUI", "bone"))
        self.comboBox_3dpca_c.setItemText(28, _translate("GENOVIS_GUI", "pink"))
        self.comboBox_3dpca_c.setItemText(29, _translate("GENOVIS_GUI", "spring"))
        self.comboBox_3dpca_c.setItemText(30, _translate("GENOVIS_GUI", "summer"))
        self.comboBox_3dpca_c.setItemText(31, _translate("GENOVIS_GUI", "autumn"))
        self.comboBox_3dpca_c.setItemText(32, _translate("GENOVIS_GUI", "winter"))
        self.comboBox_3dpca_c.setItemText(33, _translate("GENOVIS_GUI", "cool"))
        self.comboBox_3dpca_c.setItemText(34, _translate("GENOVIS_GUI", "Wistia"))
        self.comboBox_3dpca_c.setItemText(35, _translate("GENOVIS_GUI", "hot"))
        self.comboBox_3dpca_c.setItemText(36, _translate("GENOVIS_GUI", "afmhot"))
        self.comboBox_3dpca_c.setItemText(37, _translate("GENOVIS_GUI", "gist_heat"))
        self.comboBox_3dpca_c.setItemText(38, _translate("GENOVIS_GUI", "copper"))
        self.comboBox_3dpca_c.setItemText(39, _translate("GENOVIS_GUI", "PiYG"))
        self.comboBox_3dpca_c.setItemText(40, _translate("GENOVIS_GUI", "PRGn"))
        self.comboBox_3dpca_c.setItemText(41, _translate("GENOVIS_GUI", "BrBG"))
        self.comboBox_3dpca_c.setItemText(42, _translate("GENOVIS_GUI", "PuOr"))
        self.comboBox_3dpca_c.setItemText(43, _translate("GENOVIS_GUI", "RdGy"))
        self.comboBox_3dpca_c.setItemText(44, _translate("GENOVIS_GUI", "RdBu"))
        self.comboBox_3dpca_c.setItemText(45, _translate("GENOVIS_GUI", "RdYlBu"))
        self.comboBox_3dpca_c.setItemText(46, _translate("GENOVIS_GUI", "RdYlGn"))
        self.comboBox_3dpca_c.setItemText(47, _translate("GENOVIS_GUI", "Spectral"))
        self.comboBox_3dpca_c.setItemText(48, _translate("GENOVIS_GUI", "coolwarm"))
        self.comboBox_3dpca_c.setItemText(49, _translate("GENOVIS_GUI", "bwr"))
        self.comboBox_3dpca_c.setItemText(50, _translate("GENOVIS_GUI", "seismic"))
        self.comboBox_3dpca_c.setItemText(51, _translate("GENOVIS_GUI", "twilight"))
        self.comboBox_3dpca_c.setItemText(52, _translate("GENOVIS_GUI", "twilight_shifted"))
        self.comboBox_3dpca_c.setItemText(53, _translate("GENOVIS_GUI", "hsv"))
        self.comboBox_3dpca_c.setItemText(54, _translate("GENOVIS_GUI", "Pastel1"))
        self.comboBox_3dpca_c.setItemText(55, _translate("GENOVIS_GUI", "Pastel2"))
        self.comboBox_3dpca_c.setItemText(56, _translate("GENOVIS_GUI", "Paired"))
        self.comboBox_3dpca_c.setItemText(57, _translate("GENOVIS_GUI", "Accent"))
        self.comboBox_3dpca_c.setItemText(58, _translate("GENOVIS_GUI", "Dark2"))
        self.comboBox_3dpca_c.setItemText(59, _translate("GENOVIS_GUI", "Set1"))
        self.comboBox_3dpca_c.setItemText(60, _translate("GENOVIS_GUI", "Set2"))
        self.comboBox_3dpca_c.setItemText(61, _translate("GENOVIS_GUI", "Set3"))
        self.comboBox_3dpca_c.setItemText(62, _translate("GENOVIS_GUI", "tab10"))
        self.comboBox_3dpca_c.setItemText(63, _translate("GENOVIS_GUI", "tab20"))
        self.comboBox_3dpca_c.setItemText(64, _translate("GENOVIS_GUI", "tab20b"))
        self.comboBox_3dpca_c.setItemText(65, _translate("GENOVIS_GUI", "tab20c"))
        self.comboBox_3dpca_c.setItemText(66, _translate("GENOVIS_GUI", "flag"))
        self.comboBox_3dpca_c.setItemText(67, _translate("GENOVIS_GUI", "prism"))
        self.comboBox_3dpca_c.setItemText(68, _translate("GENOVIS_GUI", "ocean"))
        self.comboBox_3dpca_c.setItemText(69, _translate("GENOVIS_GUI", "gist_earth"))
        self.comboBox_3dpca_c.setItemText(70, _translate("GENOVIS_GUI", "terrain"))
        self.comboBox_3dpca_c.setItemText(71, _translate("GENOVIS_GUI", "gist_stern"))
        self.comboBox_3dpca_c.setItemText(72, _translate("GENOVIS_GUI", "gnuplot"))
        self.comboBox_3dpca_c.setItemText(73, _translate("GENOVIS_GUI", "gnuplot2"))
        self.comboBox_3dpca_c.setItemText(74, _translate("GENOVIS_GUI", "CMRmap"))
        self.comboBox_3dpca_c.setItemText(75, _translate("GENOVIS_GUI", "cubehelix"))
        self.comboBox_3dpca_c.setItemText(76, _translate("GENOVIS_GUI", "brg"))
        self.comboBox_3dpca_c.setItemText(77, _translate("GENOVIS_GUI", "gist_rainbow"))
        self.comboBox_3dpca_c.setItemText(78, _translate("GENOVIS_GUI", "rainbow"))
        self.comboBox_3dpca_c.setItemText(79, _translate("GENOVIS_GUI", "jet"))
        self.comboBox_3dpca_c.setItemText(80, _translate("GENOVIS_GUI", "turbo"))
        self.comboBox_3dpca_c.setItemText(81, _translate("GENOVIS_GUI", "nipy_spectral"))
        self.comboBox_3dpca_c.setItemText(82, _translate("GENOVIS_GUI", "gist_ncar"))
        self.label_3dpca_x.setText(_translate("GENOVIS_GUI", "--x"))
        self.label_3dpca_y.setText(_translate("GENOVIS_GUI", "--y"))
        self.label_3dpca_mode.setText(_translate("GENOVIS_GUI", "--mode"))
        self.comboBox_3dpca_mode.setItemText(0, _translate("GENOVIS_GUI", "int"))
        self.comboBox_3dpca_mode.setItemText(1, _translate("GENOVIS_GUI", "solid"))
        self.label_3dpca_azim.setText(_translate("GENOVIS_GUI", "--azim"))
        self.label_3dpca_elev.setText(_translate("GENOVIS_GUI", "--elev"))
        self.label_3dpca_fs.setText(_translate("GENOVIS_GUI", "--fs"))
        self.label_3dpca_f.setText(_translate("GENOVIS_GUI", "--f"))
        self.lineEdit_3dpca_f.setText(_translate("GENOVIS_GUI", "Calibri"))
        self.label_3dpca_dpi.setText(_translate("GENOVIS_GUI", "--dpi"))
        self.label_3dpca_ft.setText(_translate("GENOVIS_GUI", "--ft"))
        self.comboBox_3dpca_ft.setItemText(0, _translate("GENOVIS_GUI", "jpg"))
        self.comboBox_3dpca_ft.setItemText(1, _translate("GENOVIS_GUI", "jpeg"))
        self.comboBox_3dpca_ft.setItemText(2, _translate("GENOVIS_GUI", "png"))
        self.comboBox_3dpca_ft.setItemText(3, _translate("GENOVIS_GUI", "tif"))
        self.comboBox_3dpca_ft.setItemText(4, _translate("GENOVIS_GUI", "tiff"))
        self.comboBox_3dpca_ft.setItemText(5, _translate("GENOVIS_GUI", "svg"))
        self.comboBox_3dpca_ft.setItemText(6, _translate("GENOVIS_GUI", "svgz"))
        self.comboBox_3dpca_ft.setItemText(7, _translate("GENOVIS_GUI", "pdf"))
        self.comboBox_3dpca_ft.setItemText(8, _translate("GENOVIS_GUI", "eps"))
        self.comboBox_3dpca_ft.setItemText(9, _translate("GENOVIS_GUI", "pgf"))
        self.comboBox_3dpca_ft.setItemText(10, _translate("GENOVIS_GUI", "ps"))
        self.comboBox_3dpca_ft.setItemText(11, _translate("GENOVIS_GUI", "raw"))
        self.comboBox_3dpca_ft.setItemText(12, _translate("GENOVIS_GUI", "rgba"))
        self.comboBox_3dpca_ft.setItemText(13, _translate("GENOVIS_GUI", "webp"))
        self.label_3dpca_dim.setText(_translate("GENOVIS_GUI", "--dim"))
        self.comboBox_3dpca_dim.setItemText(0, _translate("GENOVIS_GUI", "3d"))
        self.comboBox_3dpca_dim.setItemText(1, _translate("GENOVIS_GUI", "2d"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.pca_tab), _translate("GENOVIS_GUI", "pca3d"))
        self.pushButton_admix_RUN.setText(_translate("GENOVIS_GUI", "Run admix"))
        self.label_admix_d.setText(_translate("GENOVIS_GUI", "--d"))
        self.pushButton_admix_d.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_admix_o.setText(_translate("GENOVIS_GUI", "--o"))
        self.lineEdit_admix_o.setText(_translate("GENOVIS_GUI", "admix_plot"))
        self.pushButton_admix_o.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_admix_sl.setText(_translate("GENOVIS_GUI", "--sl"))
        self.comboBox_admix_sl.setCurrentText(_translate("GENOVIS_GUI", "false"))
        self.comboBox_admix_sl.setItemText(0, _translate("GENOVIS_GUI", "true"))
        self.comboBox_admix_sl.setItemText(1, _translate("GENOVIS_GUI", "false"))
        self.label_admix_x.setText(_translate("GENOVIS_GUI", "--x"))
        self.label_admix_y.setText(_translate("GENOVIS_GUI", "--y"))
        self.label_admix_c.setText(_translate("GENOVIS_GUI", "--c"))
        self.comboBox_admix_c.setCurrentText(_translate("GENOVIS_GUI", "plasma"))
        self.comboBox_admix_c.setItemText(0, _translate("GENOVIS_GUI", "plasma"))
        self.comboBox_admix_c.setItemText(1, _translate("GENOVIS_GUI", "viridis"))
        self.comboBox_admix_c.setItemText(2, _translate("GENOVIS_GUI", "inferno"))
        self.comboBox_admix_c.setItemText(3, _translate("GENOVIS_GUI", "magma"))
        self.comboBox_admix_c.setItemText(4, _translate("GENOVIS_GUI", "cividis"))
        self.comboBox_admix_c.setItemText(5, _translate("GENOVIS_GUI", "Greys"))
        self.comboBox_admix_c.setItemText(6, _translate("GENOVIS_GUI", "Purples"))
        self.comboBox_admix_c.setItemText(7, _translate("GENOVIS_GUI", "Blues"))
        self.comboBox_admix_c.setItemText(8, _translate("GENOVIS_GUI", "Greens"))
        self.comboBox_admix_c.setItemText(9, _translate("GENOVIS_GUI", "Oranges"))
        self.comboBox_admix_c.setItemText(10, _translate("GENOVIS_GUI", "Reds"))
        self.comboBox_admix_c.setItemText(11, _translate("GENOVIS_GUI", "YlOrBr"))
        self.comboBox_admix_c.setItemText(12, _translate("GENOVIS_GUI", "YlOrRd"))
        self.comboBox_admix_c.setItemText(13, _translate("GENOVIS_GUI", "OrRd"))
        self.comboBox_admix_c.setItemText(14, _translate("GENOVIS_GUI", "PuRd"))
        self.comboBox_admix_c.setItemText(15, _translate("GENOVIS_GUI", "RdPu"))
        self.comboBox_admix_c.setItemText(16, _translate("GENOVIS_GUI", "BuPu"))
        self.comboBox_admix_c.setItemText(17, _translate("GENOVIS_GUI", "GnBu"))
        self.comboBox_admix_c.setItemText(18, _translate("GENOVIS_GUI", "PuBu"))
        self.comboBox_admix_c.setItemText(19, _translate("GENOVIS_GUI", "YlGnBu"))
        self.comboBox_admix_c.setItemText(20, _translate("GENOVIS_GUI", "PuBuGn"))
        self.comboBox_admix_c.setItemText(21, _translate("GENOVIS_GUI", "BuGn"))
        self.comboBox_admix_c.setItemText(22, _translate("GENOVIS_GUI", "YlGn"))
        self.comboBox_admix_c.setItemText(23, _translate("GENOVIS_GUI", "binary"))
        self.comboBox_admix_c.setItemText(24, _translate("GENOVIS_GUI", "gist_yarg"))
        self.comboBox_admix_c.setItemText(25, _translate("GENOVIS_GUI", "gist_gray"))
        self.comboBox_admix_c.setItemText(26, _translate("GENOVIS_GUI", "gray"))
        self.comboBox_admix_c.setItemText(27, _translate("GENOVIS_GUI", "bone"))
        self.comboBox_admix_c.setItemText(28, _translate("GENOVIS_GUI", "pink"))
        self.comboBox_admix_c.setItemText(29, _translate("GENOVIS_GUI", "spring"))
        self.comboBox_admix_c.setItemText(30, _translate("GENOVIS_GUI", "summer"))
        self.comboBox_admix_c.setItemText(31, _translate("GENOVIS_GUI", "autumn"))
        self.comboBox_admix_c.setItemText(32, _translate("GENOVIS_GUI", "winter"))
        self.comboBox_admix_c.setItemText(33, _translate("GENOVIS_GUI", "cool"))
        self.comboBox_admix_c.setItemText(34, _translate("GENOVIS_GUI", "Wistia"))
        self.comboBox_admix_c.setItemText(35, _translate("GENOVIS_GUI", "hot"))
        self.comboBox_admix_c.setItemText(36, _translate("GENOVIS_GUI", "afmhot"))
        self.comboBox_admix_c.setItemText(37, _translate("GENOVIS_GUI", "gist_heat"))
        self.comboBox_admix_c.setItemText(38, _translate("GENOVIS_GUI", "copper"))
        self.comboBox_admix_c.setItemText(39, _translate("GENOVIS_GUI", "PiYG"))
        self.comboBox_admix_c.setItemText(40, _translate("GENOVIS_GUI", "PRGn"))
        self.comboBox_admix_c.setItemText(41, _translate("GENOVIS_GUI", "BrBG"))
        self.comboBox_admix_c.setItemText(42, _translate("GENOVIS_GUI", "PuOr"))
        self.comboBox_admix_c.setItemText(43, _translate("GENOVIS_GUI", "RdGy"))
        self.comboBox_admix_c.setItemText(44, _translate("GENOVIS_GUI", "RdBu"))
        self.comboBox_admix_c.setItemText(45, _translate("GENOVIS_GUI", "RdYlBu"))
        self.comboBox_admix_c.setItemText(46, _translate("GENOVIS_GUI", "RdYlGn"))
        self.comboBox_admix_c.setItemText(47, _translate("GENOVIS_GUI", "Spectral"))
        self.comboBox_admix_c.setItemText(48, _translate("GENOVIS_GUI", "coolwarm"))
        self.comboBox_admix_c.setItemText(49, _translate("GENOVIS_GUI", "bwr"))
        self.comboBox_admix_c.setItemText(50, _translate("GENOVIS_GUI", "seismic"))
        self.comboBox_admix_c.setItemText(51, _translate("GENOVIS_GUI", "twilight"))
        self.comboBox_admix_c.setItemText(52, _translate("GENOVIS_GUI", "twilight_shifted"))
        self.comboBox_admix_c.setItemText(53, _translate("GENOVIS_GUI", "hsv"))
        self.comboBox_admix_c.setItemText(54, _translate("GENOVIS_GUI", "Pastel1"))
        self.comboBox_admix_c.setItemText(55, _translate("GENOVIS_GUI", "Pastel2"))
        self.comboBox_admix_c.setItemText(56, _translate("GENOVIS_GUI", "Paired"))
        self.comboBox_admix_c.setItemText(57, _translate("GENOVIS_GUI", "Accent"))
        self.comboBox_admix_c.setItemText(58, _translate("GENOVIS_GUI", "Dark2"))
        self.comboBox_admix_c.setItemText(59, _translate("GENOVIS_GUI", "Set1"))
        self.comboBox_admix_c.setItemText(60, _translate("GENOVIS_GUI", "Set2"))
        self.comboBox_admix_c.setItemText(61, _translate("GENOVIS_GUI", "Set3"))
        self.comboBox_admix_c.setItemText(62, _translate("GENOVIS_GUI", "tab10"))
        self.comboBox_admix_c.setItemText(63, _translate("GENOVIS_GUI", "tab20"))
        self.comboBox_admix_c.setItemText(64, _translate("GENOVIS_GUI", "tab20b"))
        self.comboBox_admix_c.setItemText(65, _translate("GENOVIS_GUI", "tab20c"))
        self.comboBox_admix_c.setItemText(66, _translate("GENOVIS_GUI", "flag"))
        self.comboBox_admix_c.setItemText(67, _translate("GENOVIS_GUI", "prism"))
        self.comboBox_admix_c.setItemText(68, _translate("GENOVIS_GUI", "ocean"))
        self.comboBox_admix_c.setItemText(69, _translate("GENOVIS_GUI", "gist_earth"))
        self.comboBox_admix_c.setItemText(70, _translate("GENOVIS_GUI", "terrain"))
        self.comboBox_admix_c.setItemText(71, _translate("GENOVIS_GUI", "gist_stern"))
        self.comboBox_admix_c.setItemText(72, _translate("GENOVIS_GUI", "gnuplot"))
        self.comboBox_admix_c.setItemText(73, _translate("GENOVIS_GUI", "gnuplot2"))
        self.comboBox_admix_c.setItemText(74, _translate("GENOVIS_GUI", "CMRmap"))
        self.comboBox_admix_c.setItemText(75, _translate("GENOVIS_GUI", "cubehelix"))
        self.comboBox_admix_c.setItemText(76, _translate("GENOVIS_GUI", "brg"))
        self.comboBox_admix_c.setItemText(77, _translate("GENOVIS_GUI", "gist_rainbow"))
        self.comboBox_admix_c.setItemText(78, _translate("GENOVIS_GUI", "rainbow"))
        self.comboBox_admix_c.setItemText(79, _translate("GENOVIS_GUI", "jet"))
        self.comboBox_admix_c.setItemText(80, _translate("GENOVIS_GUI", "turbo"))
        self.comboBox_admix_c.setItemText(81, _translate("GENOVIS_GUI", "nipy_spectral"))
        self.comboBox_admix_c.setItemText(82, _translate("GENOVIS_GUI", "gist_ncar"))
        self.label_admix_f.setText(_translate("GENOVIS_GUI", "--f"))
        self.lineEdit_admix_f.setText(_translate("GENOVIS_GUI", "Calibri"))
        self.label_admix_ft.setText(_translate("GENOVIS_GUI", "--ft"))
        self.comboBox_admix_ft.setItemText(0, _translate("GENOVIS_GUI", "jpg"))
        self.comboBox_admix_ft.setItemText(1, _translate("GENOVIS_GUI", "jpeg"))
        self.comboBox_admix_ft.setItemText(2, _translate("GENOVIS_GUI", "png"))
        self.comboBox_admix_ft.setItemText(3, _translate("GENOVIS_GUI", "tif"))
        self.comboBox_admix_ft.setItemText(4, _translate("GENOVIS_GUI", "tiff"))
        self.comboBox_admix_ft.setItemText(5, _translate("GENOVIS_GUI", "svg"))
        self.comboBox_admix_ft.setItemText(6, _translate("GENOVIS_GUI", "svgz"))
        self.comboBox_admix_ft.setItemText(7, _translate("GENOVIS_GUI", "pdf"))
        self.comboBox_admix_ft.setItemText(8, _translate("GENOVIS_GUI", "eps"))
        self.comboBox_admix_ft.setItemText(9, _translate("GENOVIS_GUI", "pgf"))
        self.comboBox_admix_ft.setItemText(10, _translate("GENOVIS_GUI", "ps"))
        self.comboBox_admix_ft.setItemText(11, _translate("GENOVIS_GUI", "raw"))
        self.comboBox_admix_ft.setItemText(12, _translate("GENOVIS_GUI", "rgba"))
        self.comboBox_admix_ft.setItemText(13, _translate("GENOVIS_GUI", "webp"))
        self.label_admix_lws.setText(_translate("GENOVIS_GUI", "--lws"))
        self.label_admix_dpi.setText(_translate("GENOVIS_GUI", "--dpi"))
        self.label_admix_fs.setText(_translate("GENOVIS_GUI", "--fs"))
        self.label_admix_xt.setText(_translate("GENOVIS_GUI", "--xt"))
        self.label_admix_mode.setText(_translate("GENOVIS_GUI", "--mode"))
        self.comboBox_admix_mode.setItemText(0, _translate("GENOVIS_GUI", "int"))
        self.comboBox_admix_mode.setItemText(1, _translate("GENOVIS_GUI", "solid"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.admix_tab), _translate("GENOVIS_GUI", "admix"))
        self.pushButton_rohpainter_RUN.setText(_translate("GENOVIS_GUI", "Run rohpainter"))
        self.label_rohpainter_d.setText(_translate("GENOVIS_GUI", "--d"))
        self.pushButton_rohpainter_d.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_rohpainter_i.setText(_translate("GENOVIS_GUI", "--i"))
        self.pushButton_rohpainter_i.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_rohpainter_o.setText(_translate("GENOVIS_GUI", "--o"))
        self.lineEdit_rohpainter_o.setText(_translate("GENOVIS_GUI", "roh_plot"))
        self.pushButton_rohpainter_o.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_rohpainter_Chr.setText(_translate("GENOVIS_GUI", "--Chr"))
        self.lineEdit_rohpainter_Chr.setText(_translate("GENOVIS_GUI", "Chromosome"))
        self.label_rohpainter_t.setText(_translate("GENOVIS_GUI", "--t"))
        self.lineEdit_rohpainter_t.setText(_translate("GENOVIS_GUI", "false"))
        self.label_rohpainter_tc.setText(_translate("GENOVIS_GUI", "--tc"))
        self.lineEdit_rohpainter_tc.setText(_translate("GENOVIS_GUI", "red"))
        self.label_rohpainter_tw.setText(_translate("GENOVIS_GUI", "--tw"))
        self.label_rohpainter_sl.setText(_translate("GENOVIS_GUI", "--sl"))
        self.comboBox_rohpainter_sl.setCurrentText(_translate("GENOVIS_GUI", "true"))
        self.comboBox_rohpainter_sl.setItemText(0, _translate("GENOVIS_GUI", "true"))
        self.comboBox_rohpainter_sl.setItemText(1, _translate("GENOVIS_GUI", "false"))
        self.label_rohpainter_xt.setText(_translate("GENOVIS_GUI", "--xt"))
        self.label_rohpainter_yt.setText(_translate("GENOVIS_GUI", "--yt"))
        self.label_rohpainter_x.setText(_translate("GENOVIS_GUI", "--x"))
        self.label_rohpainter_y.setText(_translate("GENOVIS_GUI", "--y"))
        self.label_rohpainter_f.setText(_translate("GENOVIS_GUI", "--f"))
        self.lineEdit_rohpainter_f.setText(_translate("GENOVIS_GUI", "Calibri"))
        self.label_rohpainter_fs.setText(_translate("GENOVIS_GUI", "--fs"))
        self.label_rohpainter_c.setText(_translate("GENOVIS_GUI", "--c"))
        self.comboBox_rohpainter_c.setItemText(0, _translate("GENOVIS_GUI", "plasma"))
        self.comboBox_rohpainter_c.setItemText(1, _translate("GENOVIS_GUI", "viridis"))
        self.comboBox_rohpainter_c.setItemText(2, _translate("GENOVIS_GUI", "inferno"))
        self.comboBox_rohpainter_c.setItemText(3, _translate("GENOVIS_GUI", "magma"))
        self.comboBox_rohpainter_c.setItemText(4, _translate("GENOVIS_GUI", "cividis"))
        self.comboBox_rohpainter_c.setItemText(5, _translate("GENOVIS_GUI", "Greys"))
        self.comboBox_rohpainter_c.setItemText(6, _translate("GENOVIS_GUI", "Purples"))
        self.comboBox_rohpainter_c.setItemText(7, _translate("GENOVIS_GUI", "Blues"))
        self.comboBox_rohpainter_c.setItemText(8, _translate("GENOVIS_GUI", "Greens"))
        self.comboBox_rohpainter_c.setItemText(9, _translate("GENOVIS_GUI", "Oranges"))
        self.comboBox_rohpainter_c.setItemText(10, _translate("GENOVIS_GUI", "Reds"))
        self.comboBox_rohpainter_c.setItemText(11, _translate("GENOVIS_GUI", "YlOrBr"))
        self.comboBox_rohpainter_c.setItemText(12, _translate("GENOVIS_GUI", "YlOrRd"))
        self.comboBox_rohpainter_c.setItemText(13, _translate("GENOVIS_GUI", "OrRd"))
        self.comboBox_rohpainter_c.setItemText(14, _translate("GENOVIS_GUI", "PuRd"))
        self.comboBox_rohpainter_c.setItemText(15, _translate("GENOVIS_GUI", "RdPu"))
        self.comboBox_rohpainter_c.setItemText(16, _translate("GENOVIS_GUI", "BuPu"))
        self.comboBox_rohpainter_c.setItemText(17, _translate("GENOVIS_GUI", "GnBu"))
        self.comboBox_rohpainter_c.setItemText(18, _translate("GENOVIS_GUI", "PuBu"))
        self.comboBox_rohpainter_c.setItemText(19, _translate("GENOVIS_GUI", "YlGnBu"))
        self.comboBox_rohpainter_c.setItemText(20, _translate("GENOVIS_GUI", "PuBuGn"))
        self.comboBox_rohpainter_c.setItemText(21, _translate("GENOVIS_GUI", "BuGn"))
        self.comboBox_rohpainter_c.setItemText(22, _translate("GENOVIS_GUI", "YlGn"))
        self.comboBox_rohpainter_c.setItemText(23, _translate("GENOVIS_GUI", "binary"))
        self.comboBox_rohpainter_c.setItemText(24, _translate("GENOVIS_GUI", "gist_yarg"))
        self.comboBox_rohpainter_c.setItemText(25, _translate("GENOVIS_GUI", "gist_gray"))
        self.comboBox_rohpainter_c.setItemText(26, _translate("GENOVIS_GUI", "gray"))
        self.comboBox_rohpainter_c.setItemText(27, _translate("GENOVIS_GUI", "bone"))
        self.comboBox_rohpainter_c.setItemText(28, _translate("GENOVIS_GUI", "pink"))
        self.comboBox_rohpainter_c.setItemText(29, _translate("GENOVIS_GUI", "spring"))
        self.comboBox_rohpainter_c.setItemText(30, _translate("GENOVIS_GUI", "summer"))
        self.comboBox_rohpainter_c.setItemText(31, _translate("GENOVIS_GUI", "autumn"))
        self.comboBox_rohpainter_c.setItemText(32, _translate("GENOVIS_GUI", "winter"))
        self.comboBox_rohpainter_c.setItemText(33, _translate("GENOVIS_GUI", "cool"))
        self.comboBox_rohpainter_c.setItemText(34, _translate("GENOVIS_GUI", "Wistia"))
        self.comboBox_rohpainter_c.setItemText(35, _translate("GENOVIS_GUI", "hot"))
        self.comboBox_rohpainter_c.setItemText(36, _translate("GENOVIS_GUI", "afmhot"))
        self.comboBox_rohpainter_c.setItemText(37, _translate("GENOVIS_GUI", "gist_heat"))
        self.comboBox_rohpainter_c.setItemText(38, _translate("GENOVIS_GUI", "copper"))
        self.comboBox_rohpainter_c.setItemText(39, _translate("GENOVIS_GUI", "PiYG"))
        self.comboBox_rohpainter_c.setItemText(40, _translate("GENOVIS_GUI", "PRGn"))
        self.comboBox_rohpainter_c.setItemText(41, _translate("GENOVIS_GUI", "BrBG"))
        self.comboBox_rohpainter_c.setItemText(42, _translate("GENOVIS_GUI", "PuOr"))
        self.comboBox_rohpainter_c.setItemText(43, _translate("GENOVIS_GUI", "RdGy"))
        self.comboBox_rohpainter_c.setItemText(44, _translate("GENOVIS_GUI", "RdBu"))
        self.comboBox_rohpainter_c.setItemText(45, _translate("GENOVIS_GUI", "RdYlBu"))
        self.comboBox_rohpainter_c.setItemText(46, _translate("GENOVIS_GUI", "RdYlGn"))
        self.comboBox_rohpainter_c.setItemText(47, _translate("GENOVIS_GUI", "Spectral"))
        self.comboBox_rohpainter_c.setItemText(48, _translate("GENOVIS_GUI", "coolwarm"))
        self.comboBox_rohpainter_c.setItemText(49, _translate("GENOVIS_GUI", "bwr"))
        self.comboBox_rohpainter_c.setItemText(50, _translate("GENOVIS_GUI", "seismic"))
        self.comboBox_rohpainter_c.setItemText(51, _translate("GENOVIS_GUI", "twilight"))
        self.comboBox_rohpainter_c.setItemText(52, _translate("GENOVIS_GUI", "twilight_shifted"))
        self.comboBox_rohpainter_c.setItemText(53, _translate("GENOVIS_GUI", "hsv"))
        self.comboBox_rohpainter_c.setItemText(54, _translate("GENOVIS_GUI", "Pastel1"))
        self.comboBox_rohpainter_c.setItemText(55, _translate("GENOVIS_GUI", "Pastel2"))
        self.comboBox_rohpainter_c.setItemText(56, _translate("GENOVIS_GUI", "Paired"))
        self.comboBox_rohpainter_c.setItemText(57, _translate("GENOVIS_GUI", "Accent"))
        self.comboBox_rohpainter_c.setItemText(58, _translate("GENOVIS_GUI", "Dark2"))
        self.comboBox_rohpainter_c.setItemText(59, _translate("GENOVIS_GUI", "Set1"))
        self.comboBox_rohpainter_c.setItemText(60, _translate("GENOVIS_GUI", "Set2"))
        self.comboBox_rohpainter_c.setItemText(61, _translate("GENOVIS_GUI", "Set3"))
        self.comboBox_rohpainter_c.setItemText(62, _translate("GENOVIS_GUI", "tab10"))
        self.comboBox_rohpainter_c.setItemText(63, _translate("GENOVIS_GUI", "tab20"))
        self.comboBox_rohpainter_c.setItemText(64, _translate("GENOVIS_GUI", "tab20b"))
        self.comboBox_rohpainter_c.setItemText(65, _translate("GENOVIS_GUI", "tab20c"))
        self.comboBox_rohpainter_c.setItemText(66, _translate("GENOVIS_GUI", "flag"))
        self.comboBox_rohpainter_c.setItemText(67, _translate("GENOVIS_GUI", "prism"))
        self.comboBox_rohpainter_c.setItemText(68, _translate("GENOVIS_GUI", "ocean"))
        self.comboBox_rohpainter_c.setItemText(69, _translate("GENOVIS_GUI", "gist_earth"))
        self.comboBox_rohpainter_c.setItemText(70, _translate("GENOVIS_GUI", "terrain"))
        self.comboBox_rohpainter_c.setItemText(71, _translate("GENOVIS_GUI", "gist_stern"))
        self.comboBox_rohpainter_c.setItemText(72, _translate("GENOVIS_GUI", "gnuplot"))
        self.comboBox_rohpainter_c.setItemText(73, _translate("GENOVIS_GUI", "gnuplot2"))
        self.comboBox_rohpainter_c.setItemText(74, _translate("GENOVIS_GUI", "CMRmap"))
        self.comboBox_rohpainter_c.setItemText(75, _translate("GENOVIS_GUI", "cubehelix"))
        self.comboBox_rohpainter_c.setItemText(76, _translate("GENOVIS_GUI", "brg"))
        self.comboBox_rohpainter_c.setItemText(77, _translate("GENOVIS_GUI", "gist_rainbow"))
        self.comboBox_rohpainter_c.setItemText(78, _translate("GENOVIS_GUI", "rainbow"))
        self.comboBox_rohpainter_c.setItemText(79, _translate("GENOVIS_GUI", "jet"))
        self.comboBox_rohpainter_c.setItemText(80, _translate("GENOVIS_GUI", "turbo"))
        self.comboBox_rohpainter_c.setItemText(81, _translate("GENOVIS_GUI", "nipy_spectral"))
        self.comboBox_rohpainter_c.setItemText(82, _translate("GENOVIS_GUI", "gist_ncar"))
        self.label_rohpainter_ft.setText(_translate("GENOVIS_GUI", "--ft"))
        self.comboBox_rohpainter_ft.setItemText(0, _translate("GENOVIS_GUI", "jpg"))
        self.comboBox_rohpainter_ft.setItemText(1, _translate("GENOVIS_GUI", "jpeg"))
        self.comboBox_rohpainter_ft.setItemText(2, _translate("GENOVIS_GUI", "png"))
        self.comboBox_rohpainter_ft.setItemText(3, _translate("GENOVIS_GUI", "tif"))
        self.comboBox_rohpainter_ft.setItemText(4, _translate("GENOVIS_GUI", "tiff"))
        self.comboBox_rohpainter_ft.setItemText(5, _translate("GENOVIS_GUI", "svg"))
        self.comboBox_rohpainter_ft.setItemText(6, _translate("GENOVIS_GUI", "svgz"))
        self.comboBox_rohpainter_ft.setItemText(7, _translate("GENOVIS_GUI", "pdf"))
        self.comboBox_rohpainter_ft.setItemText(8, _translate("GENOVIS_GUI", "eps"))
        self.comboBox_rohpainter_ft.setItemText(9, _translate("GENOVIS_GUI", "pgf"))
        self.comboBox_rohpainter_ft.setItemText(10, _translate("GENOVIS_GUI", "ps"))
        self.comboBox_rohpainter_ft.setItemText(11, _translate("GENOVIS_GUI", "raw"))
        self.comboBox_rohpainter_ft.setItemText(12, _translate("GENOVIS_GUI", "rgba"))
        self.comboBox_rohpainter_ft.setItemText(13, _translate("GENOVIS_GUI", "webp"))
        self.label_rohpainter_dpi.setText(_translate("GENOVIS_GUI", "--dpi"))
        self.label_rohpainter_mode.setText(_translate("GENOVIS_GUI", "--mode"))
        self.comboBox_rohpainter_mode.setItemText(0, _translate("GENOVIS_GUI", "int"))
        self.comboBox_rohpainter_mode.setItemText(1, _translate("GENOVIS_GUI", "solid"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.rohpainter_tab), _translate("GENOVIS_GUI", "rohpainter"))
        self.label_manplot_d.setText(_translate("GENOVIS_GUI", "--d"))
        self.pushButton_manplot_d.setText(_translate("GENOVIS_GUI", "Browse"))
        self.label_manplot_o.setText(_translate("GENOVIS_GUI", "--o"))
        self.lineEdit_manplot_o.setText(_translate("GENOVIS_GUI", "man_plot"))
        self.pushButton_manplot_o.setText(_translate("GENOVIS_GUI", "Browse"))
        self.groupBox_sug1.setTitle(_translate("GENOVIS_GUI", "Suggestive Line 1"))
        self.groupBox_sug2.setTitle(_translate("GENOVIS_GUI", "Suggestive Line 2"))
        self.label_manplot_sug2.setText(_translate("GENOVIS_GUI", "--sug2"))
        self.label_manplot_sug2lw.setText(_translate("GENOVIS_GUI", "--sug2lw"))
        self.label_manplot_sug2c.setText(_translate("GENOVIS_GUI", "--sug2c"))
        self.lineEdit_manplot_sug2c.setText(_translate("GENOVIS_GUI", "red"))
        self.label_manplot_sug1.setText(_translate("GENOVIS_GUI", "--sug1"))
        self.label_manplot_sug1lw.setText(_translate("GENOVIS_GUI", "--sug1lw"))
        self.label_manplot_sug1c.setText(_translate("GENOVIS_GUI", "--sug1c"))
        self.lineEdit_manplot_sug1c.setText(_translate("GENOVIS_GUI", "black"))
        self.pushButton_manplot_RUN.setText(_translate("GENOVIS_GUI", "Run manplot"))
        self.label_manplot_x.setText(_translate("GENOVIS_GUI", "--x"))
        self.label_manplot_y.setText(_translate("GENOVIS_GUI", "--y"))
        self.label_manplot_f.setText(_translate("GENOVIS_GUI", "--f"))
        self.lineEdit_manplot_f.setText(_translate("GENOVIS_GUI", "Calibri"))
        self.label_manplot_fs.setText(_translate("GENOVIS_GUI", "--fs"))
        self.label_manplot_ft.setText(_translate("GENOVIS_GUI", "--ft"))
        self.comboBox_manplot_ft.setItemText(0, _translate("GENOVIS_GUI", "jpg"))
        self.comboBox_manplot_ft.setItemText(1, _translate("GENOVIS_GUI", "jpeg"))
        self.comboBox_manplot_ft.setItemText(2, _translate("GENOVIS_GUI", "png"))
        self.comboBox_manplot_ft.setItemText(3, _translate("GENOVIS_GUI", "tif"))
        self.comboBox_manplot_ft.setItemText(4, _translate("GENOVIS_GUI", "tiff"))
        self.comboBox_manplot_ft.setItemText(5, _translate("GENOVIS_GUI", "svg"))
        self.comboBox_manplot_ft.setItemText(6, _translate("GENOVIS_GUI", "svgz"))
        self.comboBox_manplot_ft.setItemText(7, _translate("GENOVIS_GUI", "pdf"))
        self.comboBox_manplot_ft.setItemText(8, _translate("GENOVIS_GUI", "eps"))
        self.comboBox_manplot_ft.setItemText(9, _translate("GENOVIS_GUI", "pgf"))
        self.comboBox_manplot_ft.setItemText(10, _translate("GENOVIS_GUI", "ps"))
        self.comboBox_manplot_ft.setItemText(11, _translate("GENOVIS_GUI", "raw"))
        self.comboBox_manplot_ft.setItemText(12, _translate("GENOVIS_GUI", "rgba"))
        self.comboBox_manplot_ft.setItemText(13, _translate("GENOVIS_GUI", "webp"))
        self.label_manplot_c.setText(_translate("GENOVIS_GUI", "--c"))
        self.comboBox_manplot_c.setItemText(0, _translate("GENOVIS_GUI", "plasma"))
        self.comboBox_manplot_c.setItemText(1, _translate("GENOVIS_GUI", "viridis"))
        self.comboBox_manplot_c.setItemText(2, _translate("GENOVIS_GUI", "inferno"))
        self.comboBox_manplot_c.setItemText(3, _translate("GENOVIS_GUI", "magma"))
        self.comboBox_manplot_c.setItemText(4, _translate("GENOVIS_GUI", "cividis"))
        self.comboBox_manplot_c.setItemText(5, _translate("GENOVIS_GUI", "Greys"))
        self.comboBox_manplot_c.setItemText(6, _translate("GENOVIS_GUI", "Purples"))
        self.comboBox_manplot_c.setItemText(7, _translate("GENOVIS_GUI", "Blues"))
        self.comboBox_manplot_c.setItemText(8, _translate("GENOVIS_GUI", "Greens"))
        self.comboBox_manplot_c.setItemText(9, _translate("GENOVIS_GUI", "Oranges"))
        self.comboBox_manplot_c.setItemText(10, _translate("GENOVIS_GUI", "Reds"))
        self.comboBox_manplot_c.setItemText(11, _translate("GENOVIS_GUI", "YlOrBr"))
        self.comboBox_manplot_c.setItemText(12, _translate("GENOVIS_GUI", "YlOrRd"))
        self.comboBox_manplot_c.setItemText(13, _translate("GENOVIS_GUI", "OrRd"))
        self.comboBox_manplot_c.setItemText(14, _translate("GENOVIS_GUI", "PuRd"))
        self.comboBox_manplot_c.setItemText(15, _translate("GENOVIS_GUI", "RdPu"))
        self.comboBox_manplot_c.setItemText(16, _translate("GENOVIS_GUI", "BuPu"))
        self.comboBox_manplot_c.setItemText(17, _translate("GENOVIS_GUI", "GnBu"))
        self.comboBox_manplot_c.setItemText(18, _translate("GENOVIS_GUI", "PuBu"))
        self.comboBox_manplot_c.setItemText(19, _translate("GENOVIS_GUI", "YlGnBu"))
        self.comboBox_manplot_c.setItemText(20, _translate("GENOVIS_GUI", "PuBuGn"))
        self.comboBox_manplot_c.setItemText(21, _translate("GENOVIS_GUI", "BuGn"))
        self.comboBox_manplot_c.setItemText(22, _translate("GENOVIS_GUI", "YlGn"))
        self.comboBox_manplot_c.setItemText(23, _translate("GENOVIS_GUI", "binary"))
        self.comboBox_manplot_c.setItemText(24, _translate("GENOVIS_GUI", "gist_yarg"))
        self.comboBox_manplot_c.setItemText(25, _translate("GENOVIS_GUI", "gist_gray"))
        self.comboBox_manplot_c.setItemText(26, _translate("GENOVIS_GUI", "gray"))
        self.comboBox_manplot_c.setItemText(27, _translate("GENOVIS_GUI", "bone"))
        self.comboBox_manplot_c.setItemText(28, _translate("GENOVIS_GUI", "pink"))
        self.comboBox_manplot_c.setItemText(29, _translate("GENOVIS_GUI", "spring"))
        self.comboBox_manplot_c.setItemText(30, _translate("GENOVIS_GUI", "summer"))
        self.comboBox_manplot_c.setItemText(31, _translate("GENOVIS_GUI", "autumn"))
        self.comboBox_manplot_c.setItemText(32, _translate("GENOVIS_GUI", "winter"))
        self.comboBox_manplot_c.setItemText(33, _translate("GENOVIS_GUI", "cool"))
        self.comboBox_manplot_c.setItemText(34, _translate("GENOVIS_GUI", "Wistia"))
        self.comboBox_manplot_c.setItemText(35, _translate("GENOVIS_GUI", "hot"))
        self.comboBox_manplot_c.setItemText(36, _translate("GENOVIS_GUI", "afmhot"))
        self.comboBox_manplot_c.setItemText(37, _translate("GENOVIS_GUI", "gist_heat"))
        self.comboBox_manplot_c.setItemText(38, _translate("GENOVIS_GUI", "copper"))
        self.comboBox_manplot_c.setItemText(39, _translate("GENOVIS_GUI", "PiYG"))
        self.comboBox_manplot_c.setItemText(40, _translate("GENOVIS_GUI", "PRGn"))
        self.comboBox_manplot_c.setItemText(41, _translate("GENOVIS_GUI", "BrBG"))
        self.comboBox_manplot_c.setItemText(42, _translate("GENOVIS_GUI", "PuOr"))
        self.comboBox_manplot_c.setItemText(43, _translate("GENOVIS_GUI", "RdGy"))
        self.comboBox_manplot_c.setItemText(44, _translate("GENOVIS_GUI", "RdBu"))
        self.comboBox_manplot_c.setItemText(45, _translate("GENOVIS_GUI", "RdYlBu"))
        self.comboBox_manplot_c.setItemText(46, _translate("GENOVIS_GUI", "RdYlGn"))
        self.comboBox_manplot_c.setItemText(47, _translate("GENOVIS_GUI", "Spectral"))
        self.comboBox_manplot_c.setItemText(48, _translate("GENOVIS_GUI", "coolwarm"))
        self.comboBox_manplot_c.setItemText(49, _translate("GENOVIS_GUI", "bwr"))
        self.comboBox_manplot_c.setItemText(50, _translate("GENOVIS_GUI", "seismic"))
        self.comboBox_manplot_c.setItemText(51, _translate("GENOVIS_GUI", "twilight"))
        self.comboBox_manplot_c.setItemText(52, _translate("GENOVIS_GUI", "twilight_shifted"))
        self.comboBox_manplot_c.setItemText(53, _translate("GENOVIS_GUI", "hsv"))
        self.comboBox_manplot_c.setItemText(54, _translate("GENOVIS_GUI", "Pastel1"))
        self.comboBox_manplot_c.setItemText(55, _translate("GENOVIS_GUI", "Pastel2"))
        self.comboBox_manplot_c.setItemText(56, _translate("GENOVIS_GUI", "Paired"))
        self.comboBox_manplot_c.setItemText(57, _translate("GENOVIS_GUI", "Accent"))
        self.comboBox_manplot_c.setItemText(58, _translate("GENOVIS_GUI", "Dark2"))
        self.comboBox_manplot_c.setItemText(59, _translate("GENOVIS_GUI", "Set1"))
        self.comboBox_manplot_c.setItemText(60, _translate("GENOVIS_GUI", "Set2"))
        self.comboBox_manplot_c.setItemText(61, _translate("GENOVIS_GUI", "Set3"))
        self.comboBox_manplot_c.setItemText(62, _translate("GENOVIS_GUI", "tab10"))
        self.comboBox_manplot_c.setItemText(63, _translate("GENOVIS_GUI", "tab20"))
        self.comboBox_manplot_c.setItemText(64, _translate("GENOVIS_GUI", "tab20b"))
        self.comboBox_manplot_c.setItemText(65, _translate("GENOVIS_GUI", "tab20c"))
        self.comboBox_manplot_c.setItemText(66, _translate("GENOVIS_GUI", "flag"))
        self.comboBox_manplot_c.setItemText(67, _translate("GENOVIS_GUI", "prism"))
        self.comboBox_manplot_c.setItemText(68, _translate("GENOVIS_GUI", "ocean"))
        self.comboBox_manplot_c.setItemText(69, _translate("GENOVIS_GUI", "gist_earth"))
        self.comboBox_manplot_c.setItemText(70, _translate("GENOVIS_GUI", "terrain"))
        self.comboBox_manplot_c.setItemText(71, _translate("GENOVIS_GUI", "gist_stern"))
        self.comboBox_manplot_c.setItemText(72, _translate("GENOVIS_GUI", "gnuplot"))
        self.comboBox_manplot_c.setItemText(73, _translate("GENOVIS_GUI", "gnuplot2"))
        self.comboBox_manplot_c.setItemText(74, _translate("GENOVIS_GUI", "CMRmap"))
        self.comboBox_manplot_c.setItemText(75, _translate("GENOVIS_GUI", "cubehelix"))
        self.comboBox_manplot_c.setItemText(76, _translate("GENOVIS_GUI", "brg"))
        self.comboBox_manplot_c.setItemText(77, _translate("GENOVIS_GUI", "gist_rainbow"))
        self.comboBox_manplot_c.setItemText(78, _translate("GENOVIS_GUI", "rainbow"))
        self.comboBox_manplot_c.setItemText(79, _translate("GENOVIS_GUI", "jet"))
        self.comboBox_manplot_c.setItemText(80, _translate("GENOVIS_GUI", "turbo"))
        self.comboBox_manplot_c.setItemText(81, _translate("GENOVIS_GUI", "nipy_spectral"))
        self.comboBox_manplot_c.setItemText(82, _translate("GENOVIS_GUI", "gist_ncar"))
        self.label_manplot_dpi.setText(_translate("GENOVIS_GUI", "--dpi"))
        self.label_manplot_nc.setText(_translate("GENOVIS_GUI", "--nc"))
        self.label_manplot_ylab.setText(_translate("GENOVIS_GUI", "--ylab"))
        self.lineEdit_manplot_ylab.setText(_translate("GENOVIS_GUI", "Value"))
        self.label_manplot_xlab.setText(_translate("GENOVIS_GUI", "--xlab"))
        self.lineEdit_manplot_xlab.setText(_translate("GENOVIS_GUI", "Chromosome"))
        self.label_manplot_xt.setText(_translate("GENOVIS_GUI", "--xt"))
        self.label_manplot_yt.setText(_translate("GENOVIS_GUI", "--yt"))
        self.label_manplot_s.setText(_translate("GENOVIS_GUI", "--s"))
        self.label_manplot_a.setText(_translate("GENOVIS_GUI", "--a"))
        self.label_manplot_mode.setText(_translate("GENOVIS_GUI", "--mode"))
        self.comboBox_manplot_mode.setItemText(0, _translate("GENOVIS_GUI", "int"))
        self.comboBox_manplot_mode.setItemText(1, _translate("GENOVIS_GUI", "solid"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.manplot_tab), _translate("GENOVIS_GUI", "manplot"))
        self.textBrowser.setHtml(_translate("GENOVIS_GUI", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"justify\" style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt; font-weight:600; color:#ff0000;\">G</span><span style=\" font-size:8pt; font-weight:600; color:#ff5500;\">E</span><span style=\" font-size:8pt; font-weight:600; color:#ffff00;\">N</span><span style=\" font-size:8pt; font-weight:600; color:#0bb100;\">O</span><span style=\" font-size:8pt; font-weight:600; color:#00ffff;\">V</span><span style=\" font-size:8pt; font-weight:600; color:#0000ff;\">I</span><span style=\" font-size:8pt; font-weight:600; color:#882a7f;\">S</span><span style=\" font-size:8pt; font-weight:600;\"> – Version 1.0.3</span></p>\n"
"<p align=\"justify\" style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt;\">Developers: Siavash Salek Ardestani &amp; Elmira Mohandesan<br />Contact: </span><a href=\"siasia6650@gmail.com\"><span style=\" font-size:8pt; text-decoration: underline; color:#0000ff;\">siasia6650@gmail.com</span></a></p>\n"
"<p align=\"justify\" style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt;\">Released in 2025, GENOVIS is a visualization toolkit for population genomic analyses. It supports the generation of: Manhattan plots, three-dimensional PCA, SNP density maps, admixture plots, runs of homozygosity (ROH) intervals, and relationship matrices.</span></p></body></html>"))
    def run_mapden(self):
        from genovis import mapden
        os.environ["GENOVIS_GUI"] = "1"
        args = argparse.Namespace(
            m=self.lineEdit_m_mapden.text().strip(),
            i=self.lineEdit_i_mapden.text().strip(),
            mode=self.comboBox_mapden_mode.currentText(),
            Chr=self.lineEdit_mapden_chr.text().strip() or "Chr",
            Chrfs=(self.doubleSpinBox_mapden_Chrfs.value()),
            f=self.lineEdit_mapden_f.text().strip() or "Calibri",
            fs=(self.doubleSpinBox_mapden_fs.value()),
            x=(self.doubleSpinBox_mapden_x.value()),
            y=(self.doubleSpinBox_mapden_y.value()),
            c=self.comboBox_mapden_c.currentText(),
            b=(self.doubleSpinBox_mapden_b.value()),
            ft=self.comboBox_mapden_ft.currentText(),
            pad=(self.doubleSpinBox_mapden_pad.value()),
            dpi=(self.spinBox_mapden_dpi.value()),
            o=self.lineEdit_mapden_o.text().strip() or "mapden_plot",)
        buf_out, buf_err = io.StringIO(), io.StringIO()
        try:
            with contextlib.redirect_stdout(buf_out), contextlib.redirect_stderr(buf_err):
                rc = mapden.run(args)
            out = buf_out.getvalue().strip()
            err = buf_err.getvalue().strip()
            msg = (out + ("\n" + err if err else "")).strip() or "SNP density plot generated successfully."
            QtWidgets.QMessageBox.information(None, "Success", msg)
        except RuntimeError as e:
            QtWidgets.QMessageBox.critical(None, "Input Error", str(e))
        except Exception as e:
            QtWidgets.QMessageBox.critical(None, "Unexpected Error", f"{type(e).__name__}: {e}")
    def run_relmap(self):
        from genovis import relmap
        os.environ["GENOVIS_GUI"] = "1"
        args = argparse.Namespace(
            relfile=self.lineEdit__relmap_relfile.text().strip(),
            mode=self.comboBox_relmap_mode.currentText(),
            matindex= self.lineEdit_relmap_matindex.text().strip(),
            rf= self.comboBox_relmap_rf.currentText(),
            mask= self.comboBox_relmap_mask.currentText(),
            av= self.comboBox_relmap_av.currentText(),
            a= self.comboBox_relmap_a.currentText(),
            sl= self.comboBox_relmap_sl.currentText(),
            pfs= (self.doubleSpinBox_relmap_pfs.value()),
            afs= (self.doubleSpinBox_relmap_afs.value()),
            lws= (self.doubleSpinBox_relmap_lws.value()),
            xyfs= (self.doubleSpinBox_relmap_xyfs.value()),
            lc= self.lineEdit_relmap_lc.text().strip(),
            t= self.lineEdit_relmap_t.text().strip(),
            c=self.comboBox_relmap_c.currentText(),
            x= (self.doubleSpinBox_relmap_x.value()),
            y= (self.doubleSpinBox_relmap_y.value()),
            ft= self.comboBox_relmap_ft.currentText(),
            f=self.lineEdit_relmap_f.text().strip(),
            dpi=(self.spinBox_relmap_dpi.value()),
            o=self.lineEdit_relmap_o.text().strip()or "relmap_plot",)
        buf_out, buf_err = io.StringIO(), io.StringIO()
        try:
            with contextlib.redirect_stdout(buf_out), contextlib.redirect_stderr(buf_err):
                rc = relmap.run(args)
            out = buf_out.getvalue().strip()
            err = buf_err.getvalue().strip()
            msg = (out + ("\n" + err if err else "")).strip() or "Relationship heatmap plot generated successfully."
            QtWidgets.QMessageBox.information(None, "Success", msg)
        except RuntimeError as e:
            QtWidgets.QMessageBox.critical(None, "Input Error", str(e))
        except Exception as e:
            QtWidgets.QMessageBox.critical(None, "Unexpected Error", f"{type(e).__name__}: {e}")
    def run_3dpca(self):
        os.environ["GENOVIS_GUI"] = "1"
        from genovis import pca3d
        args = argparse.Namespace(
            evec=self.lineEdit_3dpca_evec.text().strip(),
            eval=self.lineEdit_3dpca_eval.text().strip(),
            dim=self.comboBox_3dpca_dim.currentText(),
            mode=self.comboBox_3dpca_mode.currentText(),
            elev=(self.doubleSpinBox_3dpca_elev.value()),
            azim=(self.doubleSpinBox_3dpca_azim.value()),
            fp=(self.spinBox_3dpca_fp.value()),
            sp=(self.spinBox_3dpca_sp.value()),
            tp=(self.spinBox_3dpca_tp.value()),
            c=self.comboBox_3dpca_c.currentText(),
            s=(self.doubleSpinBox_3dpca_s.value()),
            x=(self.doubleSpinBox_3dpca_x.value()),
            y=(self.doubleSpinBox_3dpca_y.value()),
            fs=(self.doubleSpinBox_3dpca_fs.value()),
            ft=self.comboBox_3dpca_ft.currentText(),
            f=self.lineEdit_3dpca_f.text().strip(),
            dpi=(self.spinBox_3dpca_dpi.value()),
            o=self.lineEdit_3dpca_o.text().strip()or "3dpca_plot",)
        buf_out, buf_err = io.StringIO(), io.StringIO()
        try:
            with contextlib.redirect_stdout(buf_out), contextlib.redirect_stderr(buf_err):
                rc = pca3d.run(args)
            out = buf_out.getvalue().strip()
            err = buf_err.getvalue().strip()
            msg = (out + ("\n" + err if err else "")).strip() or "PCA plot generated successfully."
            QtWidgets.QMessageBox.information(None, "Success", msg)
        except RuntimeError as e:
            QtWidgets.QMessageBox.critical(None, "Input Error", str(e))
        except Exception as e:
            QtWidgets.QMessageBox.critical(None, "Unexpected Error", f"{type(e).__name__}: {e}")
    def run_admix(self):
        os.environ["GENOVIS_GUI"] = "1"
        from genovis import admix
        args=argparse.Namespace(
            d=self.lineEdit_admix_d.text().strip(),
            mode=self.comboBox_admix_mode.currentText(),
            sl=self.comboBox_admix_sl.currentText(),
            lws=(self.doubleSpinBox_admix_lws.value()),
            xt=(self.doubleSpinBox_admix_xt.value()),
            x=(self.doubleSpinBox_admix_x.value()),
            y=(self.doubleSpinBox_admix_y.value()),
            fs=(self.doubleSpinBox_admix_fs.value()),
            c=self.comboBox_admix_c.currentText(),
            ft=self.comboBox_admix_ft.currentText(),
            f=self.lineEdit_admix_f.text().strip(),
            dpi=(self.spinBox_admix_dpi.value()),
            o=self.lineEdit_admix_o.text().strip()or "admix_plot",)
        buf_out, buf_err = io.StringIO(), io.StringIO()
        try:
            with contextlib.redirect_stdout(buf_out), contextlib.redirect_stderr(buf_err):
                rc = admix.run(args)
            out = buf_out.getvalue().strip()
            err = buf_err.getvalue().strip()
            msg = (out + ("\n" + err if err else "")).strip() or "Admixture plot generated successfully."
            QtWidgets.QMessageBox.information(None, "Success", msg)
        except RuntimeError as e:
            QtWidgets.QMessageBox.critical(None, "Input Error", str(e))
        except Exception as e:
            QtWidgets.QMessageBox.critical(None, "Unexpected Error", f"{type(e).__name__}: {e}")
    def run_rohpainter(self):
        os.environ["GENOVIS_GUI"] = "1"
        from genovis import rohpainter
        args=argparse.Namespace(
            d=self.lineEdit_rohpainter_d.text().strip(),
            mode=self.comboBox_rohpainter_mode.currentText(),
            i=self.lineEdit_rohpainter_i.text().strip(),
            tc=self.lineEdit_rohpainter_tc.text().strip(),
            Chr=self.lineEdit_rohpainter_Chr.text().strip(),
            sl=self.comboBox_rohpainter_sl.currentText(),
            tw=(self.doubleSpinBox_rohpainter_tw.value()),
            t=self.lineEdit_rohpainter_t.text().strip(),
            xt=(self.doubleSpinBox_rohpainter_xt.value()),
            yt=(self.doubleSpinBox_rohpainter_yt.value()),
            x=(self.doubleSpinBox_rohpainter_x.value()),
            y=(self.doubleSpinBox_rohpainter_y.value()),
            fs=(self.doubleSpinBox_rohpainter_fs.value()),
            c=self.comboBox_rohpainter_c.currentText(),
            ft=self.comboBox_rohpainter_ft.currentText(),
            f=self.lineEdit_rohpainter_f.text().strip(),
            dpi=(self.spinBox_rohpainter_dpi.value()),
            o=self.lineEdit_rohpainter_o.text().strip()or "rohpainter_plot",)
        buf_out, buf_err = io.StringIO(), io.StringIO()
        try:
            with contextlib.redirect_stdout(buf_out), contextlib.redirect_stderr(buf_err):
                rc = rohpainter.run(args)
            out = buf_out.getvalue().strip()
            err = buf_err.getvalue().strip()
            msg = (out + ("\n" + err if err else "")).strip() or "ROH plot generated successfully."
            QtWidgets.QMessageBox.information(None, "Success", msg)
        except RuntimeError as e:
            QtWidgets.QMessageBox.critical(None, "Input Error", str(e))
        except Exception as e:
            QtWidgets.QMessageBox.critical(None, "Unexpected Error", f"{type(e).__name__}: {e}")
    def run_manplot(self):
        os.environ["GENOVIS_GUI"] = "1"
        from genovis import manplot
        args = argparse.Namespace(
            d=self.lineEdit_manplot_d.text().strip(),
            mode=self.comboBox_manplot_mode.currentText(),
            xlab=self.lineEdit_manplot_xlab.text().strip(),
            ylab=self.lineEdit_manplot_ylab.text().strip(),
            a=(self.doubleSpinBox_manplot_a.value()),
            sug1=((self.doubleSpinBox_manplot_sug1.value()) if self.groupBox_sug1.isChecked() else None),
            sug1lw=((self.doubleSpinBox_manplot_sug1lw.value()) if self.groupBox_sug1.isChecked() else None),
            sug1c=(self.lineEdit_manplot_sug1c.text().strip() if self.groupBox_sug1.isChecked() else None),
            sug2=((self.doubleSpinBox_manplot_sug2.value()) if self.groupBox_sug2.isChecked() else None),
            sug2lw=((self.doubleSpinBox_manplot_sug2lw.value()) if self.groupBox_sug2.isChecked() else None),
            sug2c=(self.lineEdit_manplot_sug2c.text().strip() if self.groupBox_sug2.isChecked() else None),
            s=(self.doubleSpinBox_manplot_s.value()),
            xt=(self.doubleSpinBox_manplot_xt.value()),
            yt=(self.doubleSpinBox_manplot_yt.value()),
            x=(self.doubleSpinBox_manplot_x.value()),
            y=(self.doubleSpinBox_manplot_y.value()),
            fs=(self.doubleSpinBox_manplot_fs.value()),
            c=self.comboBox_manplot_c.currentText(),
            ft=self.comboBox_manplot_ft.currentText(),
            f=self.lineEdit_manplot_f.text().strip(),
            nc=(self.spinBox_manplot_nc.value()),
            dpi=(self.spinBox_manplot_dpi.value()),
            o=self.lineEdit_manplot_o.text().strip() or "manplot",)
        buf_out, buf_err = io.StringIO(), io.StringIO()
        try:
            with contextlib.redirect_stdout(buf_out), contextlib.redirect_stderr(buf_err):
                rc = manplot.run(args)
            out = buf_out.getvalue().strip()
            err = buf_err.getvalue().strip()
            msg = (out + ("\n" + err if err else "")).strip() or "Manhattan plot generated successfully."
            QtWidgets.QMessageBox.information(None, "Success", msg)
        except RuntimeError as e:
            QtWidgets.QMessageBox.critical(None, "Input Error", str(e))
        except Exception as e:
            QtWidgets.QMessageBox.critical(None, "Unexpected Error", f"{type(e).__name__}: {e}")
    def _browse_file(self, line_edit):
        file_path, _ = QtWidgets.QFileDialog.getOpenFileName(None,"Select File","","All Files (*)" )
        if file_path:line_edit.setText(file_path)

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    GENOVIS_GUI = QtWidgets.QMainWindow()
    ui = Ui_GENOVIS_GUI()
    ui.setupUi(GENOVIS_GUI)
    GENOVIS_GUI.show()
    sys.exit(app.exec_())

